searchNodes=[{"doc":"Calendar functions for calendars compatible with Elixir's Calendar behaviour. Cldr.Calendar supports the creation of calendars that are variations on the proleptic Cldr.Calendar.Gregorian calendar. It also adds additional functions, defined by the Cldr.Calendar behaviour, to support these derived calendars. The common purpose of these derived calendars is to support the creation and use of financial year calendars that are commonly used in business. There are two general types of calendars supported: month calendars that mirror the monthly structure of the proleptic Cldr.Calendar.Gregorian calendar but which are deemed to start the year in a month other than January. week calendars that are defined to have a 52 week structure (53 weeks in a long year). These calendars can be configured to start or end on the first, last or nearest day to the beginning or end of a Cldr.Calendar.Gregorian month. The main intent behind this structure is to have each year start and end on the same day of the week with a consistent 13-week quarterly structure than enables a more straight forware comparison with same-period-last-year financial performance.","ref":"Cldr.Calendar.html","title":"Cldr.Calendar","type":"behaviour"},{"doc":"Returns the calendar basis. Returns either :week or :month","ref":"Cldr.Calendar.html#c:calendar_base/0","title":"Cldr.Calendar.calendar_base/0","type":"callback"},{"doc":"Returns a calendar configured according to the preferences defined for a locale.","ref":"Cldr.Calendar.html#calendar_for_locale/2","title":"Cldr.Calendar.calendar_for_locale/2","type":"function"},{"doc":"Returns a calendar configured according to the preferences defined for a territory.","ref":"Cldr.Calendar.html#calendar_for_territory/2","title":"Cldr.Calendar.calendar_for_territory/2","type":"function"},{"doc":"Return the calendar module for a locale. Arguments :locale is any locale or locale name validated by Cldr.validate_locale/2 . The default is Cldr.get_locale() which returns the locale set for the current process Returns {:ok, calendar_module} or {:error, {exception, reason}} Examples iex&gt; Cldr.Calendar . calendar_from_locale &quot;en-US&quot; { :ok , Cldr.Calendar.US } iex&gt; Cldr.Calendar . calendar_from_locale &quot;en-GB-u-ca-gregory&quot; { :ok , Cldr.Calendar.GB } iex&gt; Cldr.Calendar . calendar_from_locale &quot;fa-IR&quot; { :ok , Cldr.Calendar.Persian } iex&gt; Cldr.Calendar . calendar_from_locale &quot;fa-IR-u-ca-gregory&quot; { :ok , Cldr.Calendar.IR }","ref":"Cldr.Calendar.html#calendar_from_locale/1","title":"Cldr.Calendar.calendar_from_locale/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#calendar_from_locale/2","title":"Cldr.Calendar.calendar_from_locale/2","type":"function"},{"doc":"Returns the calendar module preferred for a territory. Arguments territory is any valid ISO3166-2 code as an String.t or upcased atom() Returns {:ok, calendar_module} or {:error, {exception, reason}} Examples iex&gt; Cldr.Calendar . calendar_from_territory :US { :ok , Cldr.Calendar.US } iex&gt; Cldr.Calendar . calendar_from_territory :YY { :error , { Cldr.UnknownTerritoryError , &quot;The territory :YY is unknown&quot; } } Notes The overwhelming majority of territories have :gregorian as their first preferred calendar and therefore Cldr.Calendar.Gregorian or a derivation of it will be returned for most territories. Returning any other calendar module would require: That another calendar is preferred over :gregorian for a territory That a calendar module is available to support that calendar. As an example, Iran (territory :IR ) prefers the :persian calendar. If the optional library ex_cldr_calendars_persian is installed, the calendar module Cldr.Calendar.Persian will be returned. If it is not installed, Cldr.Calendar.Gregorian will be returned as :gregorian is the second preference for :IR .","ref":"Cldr.Calendar.html#calendar_from_territory/1","title":"Cldr.Calendar.calendar_from_territory/1","type":"function"},{"doc":"Returns a boolean indicating if a module is a Cldr.Calendar module","ref":"Cldr.Calendar.html#calendar_module?/1","title":"Cldr.Calendar.calendar_module?/1","type":"function"},{"doc":"Returns the year number for a date that is the representation used for a calendar. The calendar year may be different the the year in the struct. The struct year is designed for convertability and for date/time arithmetic. The representation in rendered calendar may be different. For example, in the Chinese calendar the cardinal year since epoch is stored in the struct but the calendar year used for representation is the sexigesimal year (a number between 1 and 60). Arguments date is any Date.t() Returns the calendar year as an integer. Examples iex&gt; Cldr.Calendar . calendar_year ~D[2019-01-01] 2019 iex&gt; Cldr.Calendar . calendar_year Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019 iex&gt; Cldr.Calendar . calendar_year Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019","ref":"Cldr.Calendar.html#calendar_year/1","title":"Cldr.Calendar.calendar_year/1","type":"function"},{"doc":"Returns a the year in a calendar year.","ref":"Cldr.Calendar.html#c:calendar_year/3","title":"Cldr.Calendar.calendar_year/3","type":"callback"},{"doc":"Returns the CLDR calendar type. Only algorithmic calendars are considered in this implementation","ref":"Cldr.Calendar.html#c:cldr_calendar_type/0","title":"Cldr.Calendar.cldr_calendar_type/0","type":"callback"},{"doc":"Returns the current date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year , :quarter , :month , :week or :day Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; Cldr.Calendar . current ~D[2019-01-01] , :day ~D[2019-01-01]","ref":"Cldr.Calendar.html#current/2","title":"Cldr.Calendar.current/2","type":"function"},{"doc":"Returns the cycle year number for a date . A related gregorian year is the gregorian year that is most closely associated with a date that is in another calendar. Arguments date is any Date.t() Returns the cyclic year as an integer. Examples iex&gt; Cldr.Calendar . cyclic_year ~D[2019-01-01] 2019 iex&gt; Cldr.Calendar . cyclic_year Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019 iex&gt; Cldr.Calendar . cyclic_year Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019","ref":"Cldr.Calendar.html#cyclic_year/1","title":"Cldr.Calendar.cyclic_year/1","type":"function"},{"doc":"Returns a the cyclic year in a calendar year.","ref":"Cldr.Calendar.html#c:cyclic_year/3","title":"Cldr.Calendar.cyclic_year/3","type":"callback"},{"doc":"Returns a date represented by a number of days since the start of the epoch. The start of the epoch is the date 0000-01-01 . Argumenets iso_days is an integer representing the number of days since the start of the epoch. calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() Example iex&gt; Cldr.Calendar . date_from_iso_days 737425 , Calendar.ISO ~D[2019-01-01] iex&gt; Cldr.Calendar . date_from_iso_days 366 , Calendar.ISO ~D[0001-01-01] iex&gt; Cldr.Calendar . date_from_iso_days 0 , Calendar.ISO ~D[0000-01-01]","ref":"Cldr.Calendar.html#date_from_iso_days/2","title":"Cldr.Calendar.date_from_iso_days/2","type":"function"},{"doc":"Returns a Date.t from a date tuple of {year, month, day} and a calendar. Arguments {year, month, day} is a tuple representing a date calendar is any module implementing the Calendar and Cldr.Calendar behaviours Returns a Date.t Examples iex&gt; Cldr.Calendar . date_from_tuple { 2019 , 3 , 25 } , Cldr.Calendar.Gregorian % Date { calendar : Cldr.Calendar.Gregorian , day : 25 , month : 3 , year : 2019 } iex&gt; Cldr.Calendar . date_from_tuple { 2019 , 2 , 29 } , Cldr.Calendar.Gregorian { :error , :invalid_date }","ref":"Cldr.Calendar.html#date_from_tuple/2","title":"Cldr.Calendar.date_from_tuple/2","type":"function"},{"doc":"Returns the number of days since the start of the epoch. The start of the epoch is the date 0000-01-01. Argumenets date is any Date.t() Returns The integer number of days since the epoch for the given date . Example iex&gt; Cldr.Calendar . date_to_iso_days ~D[2019-01-01] 737425 iex&gt; Cldr.Calendar . date_to_iso_days ~D[0001-01-01] 366 iex&gt; Cldr.Calendar . date_to_iso_days ~D[0000-01-01] 0","ref":"Cldr.Calendar.html#date_to_iso_days/1","title":"Cldr.Calendar.date_to_iso_days/1","type":"function"},{"doc":"Formats a date into a string representation Note that the output is not decorated with the calendar module name. Example iex&gt; Cldr.Calendar . date_to_string ~D[2019-12-04] &quot;2019-12-04&quot; iex&gt; Cldr.Calendar . date_to_string ~D[2019-23-04 Cldr.Calendar.NRF] &quot;2019-W23-4&quot;","ref":"Cldr.Calendar.html#date_to_string/1","title":"Cldr.Calendar.date_to_string/1","type":"function"},{"doc":"Returns the {day_of_era, era} for a date . Arguments date is any Date.t() Returns a the days since the start of the era and the era of the year as a tuple Examples iex&gt; Cldr.Calendar . day_of_era ~D[2019-01-01] { 737060 , 1 } iex&gt; Cldr.Calendar . day_of_era Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) { 737093 , 1 } iex&gt; Cldr.Calendar . day_of_era Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) { 737456 , 1 }","ref":"Cldr.Calendar.html#day_of_era/1","title":"Cldr.Calendar.day_of_era/1","type":"function"},{"doc":"See Date.day_of_week/1 .","ref":"Cldr.Calendar.html#day_of_week/1","title":"Cldr.Calendar.day_of_week/1","type":"function"},{"doc":"Returns the day of the year for a date . Arguments date is any Date.t() Returns a the day of the year as an integer Examples iex&gt; Cldr.Calendar . day_of_year ~D[2019-01-01] 1 iex&gt; Cldr.Calendar . day_of_year ~D[2016-12-31] 366 iex&gt; Cldr.Calendar . day_of_year ~D[2019-12-31] 365 iex&gt; Cldr.Calendar . day_of_year ~D[2019-52-07 Cldr.Calendar.NRF] 365 iex&gt; Cldr.Calendar . day_of_year ~D[2012-53-07 Cldr.Calendar.NRF] 372","ref":"Cldr.Calendar.html#day_of_year/1","title":"Cldr.Calendar.day_of_year/1","type":"function"},{"doc":"See Date.days_in_month/1 .","ref":"Cldr.Calendar.html#days_in_month/1","title":"Cldr.Calendar.days_in_month/1","type":"function"},{"doc":"Returns the number of days in a year","ref":"Cldr.Calendar.html#c:days_in_year/1","title":"Cldr.Calendar.days_in_year/1","type":"callback"},{"doc":"Returns the default calendar.","ref":"Cldr.Calendar.html#default_calendar/0","title":"Cldr.Calendar.default_calendar/0","type":"function"},{"doc":"Returns the extended year number for a date . Arguments date is any Date.t() Returns the extended calendar year as an integer. Examples iex&gt; Cldr.Calendar . extended_year ~D[2019-01-01] 2019 iex&gt; Cldr.Calendar . extended_year Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019 iex&gt; Cldr.Calendar . extended_year Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019","ref":"Cldr.Calendar.html#extended_year/1","title":"Cldr.Calendar.extended_year/1","type":"function"},{"doc":"Returns a the extended year in a calendar year.","ref":"Cldr.Calendar.html#c:extended_year/3","title":"Cldr.Calendar.extended_year/3","type":"callback"},{"doc":"Returns the first day of a week for a given locale. Note that the first of the first week is commonly not aligned with the first day of the year.","ref":"Cldr.Calendar.html#first_day_for_locale/1","title":"Cldr.Calendar.first_day_for_locale/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#first_day_for_locale/2","title":"Cldr.Calendar.first_day_for_locale/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#first_day_for_territory/1","title":"Cldr.Calendar.first_day_for_territory/1","type":"function"},{"doc":"Returns the first date of a year for a Date.t . Arguments date is any Date.t() Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar . first_day_of_year ~D[2019-12-01] ~D[2019-01-01]","ref":"Cldr.Calendar.html#first_day_of_year/1","title":"Cldr.Calendar.first_day_of_year/1","type":"function"},{"doc":"Returns the first date of a year in a calendar . Arguments year is any year calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar . first_day_of_year 2019 , Cldr.Calendar.Gregorian % Date { calendar : Cldr.Calendar.Gregorian , day : 1 , month : 1 , year : 2019 } iex&gt; Cldr.Calendar . first_day_of_year 2019 , Cldr.Calendar.NRF % Date { calendar : Cldr.Calendar.NRF , day : 1 , month : 1 , year : 2019 }","ref":"Cldr.Calendar.html#first_day_of_year/2","title":"Cldr.Calendar.first_day_of_year/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/1","title":"Cldr.Calendar.first_gregorian_day_of_year/1","type":"function"},{"doc":"Returns the gregorian date of the first day of of a year for a calendar . Arguments year is any integer year number calendar is any module that implements the Calendar and Cldr.Calendar behaviours or Calendar.ISO Examples iex&gt; Cldr.Calendar . first_gregorian_day_of_year 2019 , Cldr.Calendar.Gregorian % Date { calendar : Cldr.Calendar.Gregorian , day : 1 , month : 1 , year : 2019 } iex&gt; Cldr.Calendar . first_gregorian_day_of_year 2019 , Cldr.Calendar.NRF % Date { calendar : Cldr.Calendar.Gregorian , day : 3 , month : 2 , year : 2019 } iex&gt; Cldr.Calendar . first_gregorian_day_of_year ~D[2019-12-01] ~D[2019-01-01]","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/2","title":"Cldr.Calendar.first_gregorian_day_of_year/2","type":"function"},{"doc":"Returns the ordinal day number representing Friday.","ref":"Cldr.Calendar.html#friday/0","title":"Cldr.Calendar.friday/0","type":"function"},{"doc":"An inspect_fun/2 that can be configured in Inspect.Opts supporting inspection of user-defined calendars. This function can be configured in IEx for Elixir version 1.9 and later by: IEx . configure ( inspect : [ inspect_fun : &amp; Cldr.Calendar . inspect / 2 ] ) :ok","ref":"Cldr.Calendar.html#inspect/2","title":"Cldr.Calendar.inspect/2","type":"function"},{"doc":"Returns an Enumerable list of dates of a given precision of either :years , :quarters , :months , :weeks or :days Arguments date_from is a any Date.t that is the start of the sequence date_to_or_count is upper bound of the sequence as a Date.t or the number of dates in the sequence to be generated precision is one of :years , :quarters , :months , :weeks or :days The sequence is generated starting with date_from until the next date in the sequence would be after date_to . Notes The sequence can be in ascending or descending date order based upon whether date_from is greater than date_to . Returns A list of dates Examples iex&gt; d = ~D[2019-01-31] ~D[2019-01-31] iex&gt; d2 = ~D[2019-05-31] ~D[2019-05-31] iex&gt; Cldr.Calendar . interval d , 3 , :months [ ~D[2019-01-31] , ~D[2019-02-28] , ~D[2019-03-31] ] iex&gt; Cldr.Calendar . interval d , d2 , :months [ ~D[2019-01-31] , ~D[2019-02-28] , ~D[2019-03-31] , ~D[2019-04-30] , ~D[2019-05-31] ]","ref":"Cldr.Calendar.html#interval/3","title":"Cldr.Calendar.interval/3","type":"function"},{"doc":"Returns an a Stream function than can be lazily enumerated. This function has the same arguments and provides the same functionality as interval/3 exept that it is lazily evaluated. Arguments date_from is a any Date.t that is the start of the sequence date_to_or_count is upper bound of the sequence as a Date.t or the number of dates in the sequence to be generated precision is one of :years , :quarters , :months , :weeks or :days The sequence is generated starting with date_from until the next date in the sequence would be after date_to . Notes The sequence can be in ascending or descending date order based upon whether date_from is greater than date_to . Returns A list of dates Examples iex&gt; d = ~D[2019-01-31] ~D[2019-01-31] iex&gt; d2 = ~D[2019-05-31] ~D[2019-05-31] iex&gt; Cldr.Calendar . interval_stream ( d , 3 , :months ) |&gt; Enum . to_list [ ~D[2019-01-31] , ~D[2019-02-28] , ~D[2019-03-31] ] iex&gt; Cldr.Calendar . interval_stream ( d , d2 , :months ) |&gt; Enum . to_list [ ~D[2019-01-31] , ~D[2019-02-28] , ~D[2019-03-31] , ~D[2019-04-30] , ~D[2019-05-31] ]","ref":"Cldr.Calendar.html#interval_stream/3","title":"Cldr.Calendar.interval_stream/3","type":"function"},{"doc":"Returns the day of the week for a given iso_day_number Arguments iso_day_number is the number of days since the start of the epoch. See Cldr.Calendar.date_to_iso_days/1 Returns An integer representing a day of the week where Monday is represented by 1 and Sunday is represented by 7 Examples iex&gt; days = Cldr.Calendar . date_to_iso_days ~D[2019-01-01] iex&gt; Cldr.Calendar . iso_days_to_day_of_week ( days ) == Cldr.Calendar . tuesday true","ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1","title":"Cldr.Calendar.iso_days_to_day_of_week/1","type":"function"},{"doc":"Returns the ISO week number for a date . Arguments date is any Date.t() Returns a the ISO week of the year as an integer or {:error, :not_defined} is the calendar does not support the concept of weeks. Examples iex&gt; Cldr.Calendar . iso_week_of_year ~D[2019-01-01] { 2019 , 1 } iex&gt; Cldr.Calendar . iso_week_of_year ~D[2019-02-01] { 2019 , 5 } iex&gt; Cldr.Calendar . iso_week_of_year ~D[2019-52-01 Cldr.Calendar.NRF] { 2020 , 4 } iex&gt; Cldr.Calendar . iso_week_of_year ~D[2019-26-01 Cldr.Calendar.NRF] { 2019 , 30 } iex&gt; Cldr.Calendar . iso_week_of_year ~D[2019-12-01 Cldr.Calendar.Julian] { :error , :not_defined }","ref":"Cldr.Calendar.html#iso_week_of_year/1","title":"Cldr.Calendar.iso_week_of_year/1","type":"function"},{"doc":"Returns a tuple of {year, week_in_year} for a given year , month or week , and day for a a calendar. The iso_week_of_year is calculated based on the ISO calendar.","ref":"Cldr.Calendar.html#c:iso_week_of_year/3","title":"Cldr.Calendar.iso_week_of_year/3","type":"callback"},{"doc":"Returns the last date of a year for a Date.t . Arguments date is any Date.t() Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar . last_day_of_year ~D[2019-01-01] ~D[2019-12-31]","ref":"Cldr.Calendar.html#last_day_of_year/1","title":"Cldr.Calendar.last_day_of_year/1","type":"function"},{"doc":"Returns the last date of a year for a calendar . Arguments year is any year calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.Gregorian ) % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 12 , year : 2019 } iex&gt; Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) % Date { calendar : Cldr.Calendar.NRF , day : 7 , month : 52 , year : 2019 }","ref":"Cldr.Calendar.html#last_day_of_year/2","title":"Cldr.Calendar.last_day_of_year/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/1","title":"Cldr.Calendar.last_gregorian_day_of_year/1","type":"function"},{"doc":"Returns the gregorian date of the first day of a year for a calendar . Arguments year is any integer year number calendar is any module that implements the Calendar and Cldr.Calendar behaviours or Calendar.ISO Examples iex&gt; Cldr.Calendar . last_gregorian_day_of_year 2019 , Cldr.Calendar.Gregorian % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 12 , year : 2019 } iex&gt; Cldr.Calendar . last_gregorian_day_of_year 2019 , Cldr.Calendar.NRF % Date { calendar : Cldr.Calendar.Gregorian , day : 1 , month : 2 , year : 2020 } iex&gt; Cldr.Calendar . last_gregorian_day_of_year ~D[2019-12-01] ~D[2019-12-31]","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/2","title":"Cldr.Calendar.last_gregorian_day_of_year/2","type":"function"},{"doc":"Returns a localized string for a part of a Date.t . Arguments date_ is any Date.t part is one of :era , :quarter , :month , :day_of_week or :days_of_week options is a Keyword list of options Options :locale is any valid locale name in the list returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 . The default is Cldr.get_locale() . backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is default_backend/0 . :format is one of :wide , :abbreviated or :narrow . The default is :abbreviated . Returns A string representing the localized date part, or A list of strings representing the days of the week for the part :days_of_week . The days are in week order for the given date's calendar {error, {exception_module, message}} if an error is detected Examples iex&gt; Cldr.Calendar . localize ~D[2019-01-01] , :era &quot;AD&quot; iex&gt; Cldr.Calendar . localize ~D[2019-01-01] , :day_of_week &quot;Tue&quot; iex&gt; Cldr.Calendar . localize ~D[0001-01-01] , :day_of_week &quot;Mon&quot; iex&gt; Cldr.Calendar . localize ~D[2019-01-01] , :days_of_week [ { 1 , &quot;Mon&quot; } , { 2 , &quot;Tue&quot; } , { 3 , &quot;Wed&quot; } , { 4 , &quot;Thu&quot; } , { 5 , &quot;Fri&quot; } , { 6 , &quot;Sat&quot; } , { 7 , &quot;Sun&quot; } ] iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :era &quot;AD&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :quarter &quot;Q2&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :month &quot;Jun&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week &quot;Sat&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , format : :wide &quot;Saturday&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , format : :narrow &quot;S&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , locale : &quot;ar&quot; &quot;السبت&quot;","ref":"Cldr.Calendar.html#localize/3","title":"Cldr.Calendar.localize/3","type":"function"},{"doc":"Returns the minimum days in the first week of a year for a given locale.","ref":"Cldr.Calendar.html#min_days_for_locale/1","title":"Cldr.Calendar.min_days_for_locale/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#min_days_for_locale/2","title":"Cldr.Calendar.min_days_for_locale/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#min_days_for_territory/1","title":"Cldr.Calendar.min_days_for_territory/1","type":"function"},{"doc":"Decrements a date or date range by an integer amount of a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year , :quarter , :month , :week or :day options is a Keyword list of options Options :coerce is a boolean which, when set to true will coerce the month and/or day to be a valid date. This affects,for example, moving to the previous month from ~D[2019-03-31] . Sincce there is no date ~D[2019-02-31] this would normally return {:error, :invalid_date} . Setting coerce: true it will return ~D[2019-02-28] . Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; Cldr.Calendar . minus ~D[2016-03-01] , :days , 1 ~D[2016-02-29] iex&gt; Cldr.Calendar . minus ~D[2019-03-01] , :months , 1 ~D[2019-02-01] iex&gt; Cldr.Calendar . minus ~D[2016-03-01] , :days , 1 ~D[2016-02-29] iex&gt; Cldr.Calendar . minus ~D[2019-03-01] , :days , 1 ~D[2019-02-28] iex&gt; Cldr.Calendar . minus ~D[2019-03-01] , :months , 1 ~D[2019-02-01] iex&gt; Cldr.Calendar . minus ~D[2019-03-01] , :quarters , 1 ~D[2018-12-01] iex&gt; Cldr.Calendar . minus ~D[2019-03-01] , :years , 1 ~D[2018-03-01]","ref":"Cldr.Calendar.html#minus/4","title":"Cldr.Calendar.minus/4","type":"function"},{"doc":"Returns the Modified Julian Day of a Date.t . Arguments date is any Date.t() Returns an integer number representing the Modified Julian Day of the date Notes The Modified Julian Day is the number of days since November 17, 1858. Therefore this function only returns valid values for dates after this date. Examples iex&gt; Cldr.Calendar . modified_julian_day ~D[2019-01-01] 58484","ref":"Cldr.Calendar.html#modified_julian_day/1","title":"Cldr.Calendar.modified_julian_day/1","type":"function"},{"doc":"Returns the ordinal day number representing Monday","ref":"Cldr.Calendar.html#monday/0","title":"Cldr.Calendar.monday/0","type":"function"},{"doc":"Returns a date range representing the days in a given month for a calendar year.","ref":"Cldr.Calendar.html#c:month/2","title":"Cldr.Calendar.month/2","type":"callback"},{"doc":"Returns the month number for a date . Arguments date is any Date.t() Returns a the month of the year as an integer Examples iex&gt; Cldr.Calendar . month_of_year ~D[2019-01-01] 1 iex&gt; Cldr.Calendar . month_of_year ~D[2019-12-01] 12 iex&gt; Cldr.Calendar . month_of_year ~D[2019-52-01 Cldr.Calendar.NRF] 12 iex&gt; Cldr.Calendar . month_of_year ~D[2019-26-01 Cldr.Calendar.NRF] 6","ref":"Cldr.Calendar.html#month_of_year/1","title":"Cldr.Calendar.month_of_year/1","type":"function"},{"doc":"Returns the month for a given year , month or week , and day for a a calendar. The month_of_year is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:month_of_year/3","title":"Cldr.Calendar.month_of_year/3","type":"callback"},{"doc":"See Date.months_in_year/1 .","ref":"Cldr.Calendar.html#months_in_year/1","title":"Cldr.Calendar.months_in_year/1","type":"function"},{"doc":"Creates a new calendar based upon the provided configuration. If a module exists with the calendar_module name then it is returned, not recreated. Arguments calendar_module is am atom representing the module name of the created calendar. calendar_type is an atom of either :month or :week indicating whcih type of calendar is to be created config is a Keyword list defining the configuration of the calendar. Returns {:ok, module} where module is the new calendar module that conforms to the Calendar and Cldr.Calendar behaviours or {:module_already_exists, module} if a module of the given calendar name already exists. It is not guaranteed that the module is in fact a calendar module in this case. Configuration options The following options can be provided to create a new calendar. :cldr_backend defines a default backend module to be used for this calendar. The default is nil . :weeks_in_month defines the layout of weeks in a quarter for a week- or month- based calendar. The value must be one of [4, 4, 5] , [4,5,4] or [5,4,4] . The default is [4,4,5] . This option is ignored for :month based calendars that have the parameter day_of_year: :first . :begins_or_ends determines whether the calendar year begins or ends on the given :day_of_week and :month_of_year . The default is :begins . :first_or_last determines whether the calendar year starts (or ends) on the first, last or nearest :day-of_week and :month_of_year . The default is :first :day_of_week determines the day of the week on which this calendar begins or ends. It may be a number in the range 1..7 representing Monday to Sunday. It may also be :first indicating the the weeks are calculated from the first day of the calendar day irrespective of the day of the week. In this case the last week of the year may be less than 7 days in length. The default is 1 . :month_of_year determines the Cldr.Calendar.Gregorian month of year in which this calendar begins or ends. The default is 1 . :year is used to determine which calendar Greogian year is applicable for a given calendar date. The valid options are :first , :last and majority . The default is :majority . :min_days_in_first_week is used to determine how many days of the Cldr.Calendar.Gregorian year must be in the first week of a calendar year. This is used when determining when the year starts for week-based years. The default is 4 which is consistent with the ISO Week calendar Examples Each calendar has a function __config__/0 generated within it and therefore the configuraiton of the included calendars in ex_cldr_calendars provide insight into the behaviour of the configuration parameters. As an example here we define the ISO Week calendar calendar in full: defmodule ISOWeek do use Cldr.Calendar.Base.Week , day_of_week : 1 , # Weeks begin or end on Monday month_of_year : 1 , # Years begin or end in January min_days_in_first_week , 4 , # 4 Cldr.Calendar.Gregorian days of the year must be in the first week begins_or_ends : :begins , # The year *begins* on the `day_of_week` and `month_of_year` first_or_last : :first , # They year *begins* on the *first* `day_of_week` and `month_of_year` weeks_in_month : [ 4 , 5 , 4 ] , # The weeks are laid out as *months* in a `[4,5,4]` pattern year : :majority , # Any given year is that in which the majority of Cldr.Calendar.Gregorian months fall cldr_backend : nil , # No default `cldr_backend` is configured. locale : nil # No `locale` is used to aid configuration end This can be generated at runtime by: iex&gt; Cldr.Calendar . new ISOWeek , :week , ...&gt; day_of_week : 1 , ...&gt; month_of_year : 1 , ...&gt; min_days_in_first_week : 4 , ...&gt; begins_or_ends : :begins , ...&gt; first_or_last : :first , ...&gt; weeks_in_month : [ 4 , 5 , 4 ] , ...&gt; year : :majority , ...&gt; cldr_backend : nil { :ok , ISOWeek } Note that Cldr.Calendar.ISOWeek is included as part of this library.","ref":"Cldr.Calendar.html#new/3","title":"Cldr.Calendar.new/3","type":"function"},{"doc":"Returns the next date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year , :quarter , :month , :week or :day Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; Cldr.Calendar . next ~D[2019-01-01] , :day ~D[2019-01-02] iex&gt; Cldr.Calendar . next ~D[2019-01-01] , :month ~D[2019-02-01] iex&gt; Cldr.Calendar . next ~D[2019-01-01] , :quarter ~D[2019-04-01] iex&gt; Cldr.Calendar . next ~D[2019-01-01] , :year ~D[2020-01-01]","ref":"Cldr.Calendar.html#next/3","title":"Cldr.Calendar.next/3","type":"function"},{"doc":"Returns the number of periods (which are months in a month calendar and weeks in a week calendar) in a year","ref":"Cldr.Calendar.html#c:periods_in_year/1","title":"Cldr.Calendar.periods_in_year/1","type":"callback"},{"doc":"Adds a duration to a date Arguments date is any map that conforms to Calendar.date() duration is any duration returned by Cldr.Calendar.Duration.new!/2 options is a Keyword list of options Options Options are those applicatable to Cldr.Calendar.plus/4 Returns A date advanced by the duration Examples iex&gt; Cldr.Calendar . plus ~D[2020-01-01] , ...&gt; Cldr.Calendar.Duration . new! ( ~D[2020-01-01] , ~D[2020-02-01] ) ~D[2020-02-01] iex&gt; Cldr.Calendar . plus ~D[2020-01-01] , ...&gt; Cldr.Calendar.Duration . new! ( ~D[2020-01-01] , ~D[2020-01-02] ) ~D[2020-01-02] iex&gt; Cldr.Calendar . plus ~D[2020-01-01] , ...&gt; Cldr.Calendar.Duration . new! ( ~D[2020-01-01] , ~D[2020-02-01] ) ~D[2020-02-01] iex&gt; Cldr.Calendar . plus ~D[2020-01-01] , ...&gt; Cldr.Calendar.Duration . new! ( ~D[2020-01-01] , ~D[2021-02-01] ) ~D[2021-02-01]","ref":"Cldr.Calendar.html#plus/2","title":"Cldr.Calendar.plus/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.html#plus/3","title":"Cldr.Calendar.plus/3","type":"function"},{"doc":"Increments a date or date range by an integer amount of a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year , :quarter , :month , :week or :day options is a Keyword list of options Options :coerce is a boolean which, when set to true will coerce the month and/or day to be a valid date. This affects,for example, moving to the previous month from ~D[2019-03-31] . Sincce there is no date ~D[2019-02-31] this would normally return {:error, :invalid_date} . Setting coerce: true it will return ~D[2019-02-28] . Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; Cldr.Calendar . plus ~D[2016-02-29] , :days , 1 ~D[2016-03-01] iex&gt; Cldr.Calendar . plus ~D[2019-03-01] , :months , 1 ~D[2019-04-01] iex&gt; Cldr.Calendar . plus ~D[2016-02-29] , :days , 1 ~D[2016-03-01] iex&gt; Cldr.Calendar . plus ~D[2019-02-28] , :days , 1 ~D[2019-03-01] iex&gt; Cldr.Calendar . plus ~D[2019-03-01] , :months , 1 ~D[2019-04-01] iex&gt; Cldr.Calendar . plus ~D[2019-03-01] , :quarters , 1 ~D[2019-06-01] iex&gt; Cldr.Calendar . plus ~D[2019-03-01] , :years , 1 ~D[2020-03-01]","ref":"Cldr.Calendar.html#plus/4","title":"Cldr.Calendar.plus/4","type":"function"},{"doc":"Increments a Date.t or Date.Range.t by a specified positive or negative integer number of periods (year, quarter, month, week or day). Calendars need only implement this callback for :months and :quarters since all other date periods can be derived.","ref":"Cldr.Calendar.html#c:plus/6","title":"Cldr.Calendar.plus/6","type":"callback"},{"doc":"Returns the previous date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year , :quarter , :month , :week or :day options is a Keyword list of options that is passed to plus/4 or minus/4 Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; Cldr.Calendar . previous ~D[2019-01-01] , :day ~D[2018-12-31] iex&gt; Cldr.Calendar . previous ~D[2019-01-01] , :quarter ~D[2018-10-01] iex&gt; Cldr.Calendar . previous ~D[2019-01-01] , :month ~D[2018-12-01] iex&gt; Cldr.Calendar . previous ~D[2019-01-01] , :year ~D[2018-01-01]","ref":"Cldr.Calendar.html#previous/3","title":"Cldr.Calendar.previous/3","type":"function"},{"doc":"Returns a date range representing the days in a given quarter for a calendar year.","ref":"Cldr.Calendar.html#c:quarter/2","title":"Cldr.Calendar.quarter/2","type":"callback"},{"doc":"Returns the quarter number for a date . Arguments date is any Date.t() Returns a the quarter of the year as an integer Examples iex&gt; Cldr.Calendar . quarter_of_year ~D[2019-01-01] 1 iex&gt; Cldr.Calendar . quarter_of_year Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) 1 iex&gt; Cldr.Calendar . quarter_of_year Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) 4","ref":"Cldr.Calendar.html#quarter_of_year/1","title":"Cldr.Calendar.quarter_of_year/1","type":"function"},{"doc":"Returns the related gregorian year number for a date . A related gregorian year is the gregorian year that is most closely associated with a date that is in another calendar. Arguments date is any Date.t() Returns the related gregorian year as an integer. Examples iex&gt; Cldr.Calendar . related_gregorian_year ~D[2019-01-01] 2019 iex&gt; Cldr.Calendar . related_gregorian_year Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019 iex&gt; Cldr.Calendar . related_gregorian_year Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) 2019","ref":"Cldr.Calendar.html#related_gregorian_year/1","title":"Cldr.Calendar.related_gregorian_year/1","type":"function"},{"doc":"Returns a the related year in a calendar year.","ref":"Cldr.Calendar.html#c:related_gregorian_year/3","title":"Cldr.Calendar.related_gregorian_year/3","type":"callback"},{"doc":"","ref":"Cldr.Calendar.html#same_as_default?/1","title":"Cldr.Calendar.same_as_default?/1","type":"function"},{"doc":"Returns the ordinal day number representing Saturday.","ref":"Cldr.Calendar.html#saturday/0","title":"Cldr.Calendar.saturday/0","type":"function"},{"doc":"Returns the ordinal day number representing Sunday.","ref":"Cldr.Calendar.html#sunday/0","title":"Cldr.Calendar.sunday/0","type":"function"},{"doc":"Returns the ordinal day number representing Thursday.","ref":"Cldr.Calendar.html#thursday/0","title":"Cldr.Calendar.thursday/0","type":"function"},{"doc":"Returns the ordinal day number representing Tuesday.","ref":"Cldr.Calendar.html#tuesday/0","title":"Cldr.Calendar.tuesday/0","type":"function"},{"doc":"Validates if the argument is a Cldr.Calendar calendar module. Arguments calendar_module is a module that implements the Cldr.Calendar behaviour Returns {:ok, calendar_module} or {:error, {exception, reason}} Examples iex&gt; Cldr.Calendar . validate_calendar Cldr.Calendar.Gregorian { :ok , Cldr.Calendar.Gregorian } iex&gt; Cldr.Calendar . validate_calendar :not_a_calendar { :error , { Cldr.InvalidCalendarModule , &quot;:not_a_calendar is not a calendar module.&quot; } }","ref":"Cldr.Calendar.html#validate_calendar/1","title":"Cldr.Calendar.validate_calendar/1","type":"function"},{"doc":"Returns the ordinal day number representing Wednesday.","ref":"Cldr.Calendar.html#wednesday/0","title":"Cldr.Calendar.wednesday/0","type":"function"},{"doc":"Returns a date range representing the days in a given week for a calendar year.","ref":"Cldr.Calendar.html#c:week/2","title":"Cldr.Calendar.week/2","type":"callback"},{"doc":"Returns the {month, week_number} for a date . The nature of a week depends on the calendar configuration and therefore some results may be surprising. For example the date of December 31st 2018 is actually in month one of the ISO Week calendar of 2019. Arguments date is any Date.t() Returns a tuple of the form {month, week} or {:error, :not_defined} if the calendar does not support the concept of weeks. Examples iex&gt; Cldr.Calendar . week_of_month ( ~D[2019-01-01] ) { 1 , 1 } iex&gt; Cldr.Calendar . week_of_month ( ~D[2018-12-31] ) { 1 , 1 } iex&gt; Cldr.Calendar . week_of_month ( ~D[2019-01-01 Cldr.Calendar.BasicWeek] ) { 1 , 1 } iex&gt; Cldr.Calendar . week_of_month ( ~D[2018-12-31 Cldr.Calendar.BasicWeek] ) { 12 , 5 } iex&gt; Cldr.Calendar . week_of_month ( ~D[2018-12-31 Cldr.Calendar.Julian] ) { :error , :not_defined }","ref":"Cldr.Calendar.html#week_of_month/1","title":"Cldr.Calendar.week_of_month/1","type":"function"},{"doc":"Returns a tuple of {month, week_in_month} for a given year , month or week , and day for a a calendar. The week_in_month is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:week_of_month/3","title":"Cldr.Calendar.week_of_month/3","type":"callback"},{"doc":"Returns the {year, week_number} for a date . Arguments date is any Date.t() Returns a the week of the year as an integer or {:error, :not_defined} if the calendar does not support the concept of weeks. Examples iex&gt; Cldr.Calendar . week_of_year ~D[2019-01-01] { 2019 , 1 } iex&gt; Cldr.Calendar . week_of_year ~D[2019-12-01] { 2019 , 48 } iex&gt; Cldr.Calendar . week_of_year ~D[2019-52-01 Cldr.Calendar.NRF] { 2019 , 52 } iex&gt; Cldr.Calendar . week_of_year ~D[2019-26-01 Cldr.Calendar.NRF] { 2019 , 26 } iex&gt; Cldr.Calendar . week_of_year ~D[2019-12-01 Cldr.Calendar.Julian] { :error , :not_defined }","ref":"Cldr.Calendar.html#week_of_year/1","title":"Cldr.Calendar.week_of_year/1","type":"function"},{"doc":"Returns a tuple of {year, week_in_year} for a given year , month or week , and day for a a calendar. The week_in_year is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:week_of_year/3","title":"Cldr.Calendar.week_of_year/3","type":"callback"},{"doc":"Returns whether a given date is a weekday. Weekdays are locale-specific and depend on the policies of a given territory (country). Arguments date is any Date.t() options is a Keyword list of options Options :locale is any locale or locale name validated by Cldr.validate_locale/2 . The default is Cldr.get_locale() which returns the locale set for the current process :territory is any valid ISO-3166-2 territory that is validated by Cldr.validate_territory/1 :backend is any Cldr backend module. See the backend configuration documentation for further information. The default is Cldr.Calendar.Backend.Default which configures only the en locale. Notes When identifying which territory context within which to determine whether a given day is a weekday or not the following order applies: A territory specified by the :territory option The territory defined as part of the :locale option The territory defined as part of the current processes default locale. Examples # The defalt locale for `Cldr` is `en-001` for which # the territory is `001` (the world). The weekdays # for `001` are Monday to Friday iex&gt; Cldr.Calendar . weekday? ~D[2019-03-23] , locale : &quot;en&quot; false iex&gt; Cldr.Calendar . weekday? ~D[2019-03-23] , territory : &quot;IS&quot; false # Saturday is a weekday in India iex&gt; Cldr.Calendar . weekday? ~D[2019-03-23] , locale : &quot;en-IN&quot; , backend : MyApp.Cldr true # Friday is not a weekday in Saudi Arabia iex&gt; Cldr.Calendar . weekday? ~D[2019-03-22] , locale : &quot;ar-SA&quot; , backend : MyApp.Cldr false # Friday is not a weekday in Israel iex&gt; Cldr.Calendar . weekday? ~D[2019-03-22] , locale : &quot;he&quot; , backend : MyApp.Cldr false","ref":"Cldr.Calendar.html#weekday?/2","title":"Cldr.Calendar.weekday?/2","type":"function"},{"doc":"Returns a list of the days of the week that are considered a weekend for a given territory (country) Arguments territory is any valid ISO3166-2 code Returns A list of integers representing the days of the week that are week days Notes The list of days may not my monotonic. See the example for Saudi Arabia below. Examples iex&gt; Cldr.Calendar . weekdays ( &quot;US&quot; ) [ 1 , 2 , 3 , 4 , 5 ] iex&gt; Cldr.Calendar . weekdays ( &quot;IN&quot; ) [ 1 , 2 , 3 , 4 , 5 , 6 ] iex&gt; Cldr.Calendar . weekdays ( &quot;SA&quot; ) [ 1 , 2 , 3 , 4 , 7 ] iex&gt; Cldr.Calendar . weekdays ( &quot;yy&quot; ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; yy \\&quot; is unknown&quot; } }","ref":"Cldr.Calendar.html#weekdays/1","title":"Cldr.Calendar.weekdays/1","type":"function"},{"doc":"Returns a list of the days of the week that are considered a weekend for a given territory (country) Arguments territory is any valid ISO3166-2 code Returns A list of integers representing the days of the week that are weekend days Examples iex&gt; Cldr.Calendar . weekend ( &quot;US&quot; ) [ 6 , 7 ] iex&gt; Cldr.Calendar . weekend ( &quot;IN&quot; ) [ 7 ] iex&gt; Cldr.Calendar . weekend ( &quot;SA&quot; ) [ 5 , 6 ] iex&gt; Cldr.Calendar . weekend ( &quot;yy&quot; ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; yy \\&quot; is unknown&quot; } }","ref":"Cldr.Calendar.html#weekend/1","title":"Cldr.Calendar.weekend/1","type":"function"},{"doc":"Returns whether a given date is a weekend day. Weekend days are locale-specific and depend on the policies of a given territory (country). Arguments date is any Date.t() options is a Keyword list of options Options :locale is any locale or locale name validated by Cldr.validate_locale/2 . The default is Cldr.get_locale() which returns the locale set for the current process :territory is any valid ISO-3166-2 territory that is validated by Cldr.validate_territory/1 :backend is any Cldr backend module. See the backend configuration documentation for further information. The default is Cldr.Calendar.Backend.Default which configures only the en locale. Notes When identifying which territory context within which to determine whether a given day is a weekend or not the following order applies: A territory specified by the :territory option The territory defined as part of the :locale option The territory defined as part of the current processes default locale. Examples # The defalt locale for `Cldr` is `en-001` for which # the territory is `001` (the world). The weekend # for `001` is Saturday and Sunday iex&gt; Cldr.Calendar . weekend? ~D[2019-03-23] true iex&gt; Cldr.Calendar . weekend? ~D[2019-03-23] , locale : &quot;en&quot; true iex&gt; Cldr.Calendar . weekend? ~D[2019-03-23] , territory : &quot;IS&quot; true # In India the official weekend is only Sunday iex&gt; Cldr.Calendar . weekend? ~D[2019-03-23] , locale : &quot;en-IN&quot; , backend : MyApp.Cldr false # In Israel the weekend starts on Friday iex&gt; Cldr.Calendar . weekend? ~D[2019-03-22] , locale : &quot;he&quot; , backend : MyApp.Cldr true # As it also does in Saudia Arabia iex&gt; Cldr.Calendar . weekend? ~D[2019-03-22] , locale : &quot;ar-SA&quot; , backend : MyApp.Cldr true # Sunday is not a weekend day in Saudi Arabia iex&gt; Cldr.Calendar . weekend? ~D[2019-03-24] , locale : &quot;ar-SA&quot; , backend : MyApp.Cldr false","ref":"Cldr.Calendar.html#weekend?/2","title":"Cldr.Calendar.weekend?/2","type":"function"},{"doc":"Returns the number of weeks in a year. Arguments Either a Date.t() or an integer year a calendar name Returns In integer number of weeks in a year Examples iex&gt; Cldr.Calendar . weeks_in_year ~D[2026-W01-1 Cldr.Calendar.ISOWeek] 53 iex&gt; Cldr.Calendar . weeks_in_year ~D[2019-01-01] 52 iex&gt; Cldr.Calendar . weeks_in_year ~D[2020-01-01] 52 iex&gt; Cldr.Calendar . weeks_in_year 2020 , Cldr.Calendar.ISOWeek 53","ref":"Cldr.Calendar.html#weeks_in_year/1","title":"Cldr.Calendar.weeks_in_year/1","type":"function"},{"doc":"Returns the number of weeks in a year","ref":"Cldr.Calendar.html#c:weeks_in_year/1","title":"Cldr.Calendar.weeks_in_year/1","type":"callback"},{"doc":"","ref":"Cldr.Calendar.html#weeks_in_year/2","title":"Cldr.Calendar.weeks_in_year/2","type":"function"},{"doc":"Returns the number of days in n weeks Example iex&gt; Cldr.Calendar . weeks_to_days ( 2 ) 14","ref":"Cldr.Calendar.html#weeks_to_days/1","title":"Cldr.Calendar.weeks_to_days/1","type":"function"},{"doc":"Returns a date range representing the days in a calendar year.","ref":"Cldr.Calendar.html#c:year/1","title":"Cldr.Calendar.year/1","type":"callback"},{"doc":"Returns the {year_of_era, era} for a date . This function differs slightly from Date.year_of_era/1 . See the notes below Arguments date is any Date.t() Returns a the year since the start of the era and the era of the year as a tuple Notes Unlike Date.year_of_era/1 , this function supports eras that change part way through the calendar year. This is common in the Japanese calendar where the eras change when a new emperor is ordained which can happen at any time of year. Therefore this function is consistent with Date.year_of_era/1 for the Gregorian and related calendars, but returns a different (and more accurate) result for the Japanese calendar. This is also true for fiscal year calendars that start on a day other than January 1st. The year of era will depend on whether the calendar was configured with year: :beginning , year: :ending or year: :majority Examples iex&gt; Cldr.Calendar . year_of_era ~D[2019-01-01] { 2019 , 1 } iex&gt; Cldr.Calendar . year_of_era Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.NRF ) { 2019 , 1 } iex&gt; Cldr.Calendar . year_of_era Cldr.Calendar . last_day_of_year ( 2019 , Cldr.Calendar.NRF ) { 2019 , 1 }","ref":"Cldr.Calendar.html#year_of_era/1","title":"Cldr.Calendar.year_of_era/1","type":"function"},{"doc":"Specifies the type of a calendar. A calendar is a module that implements the Calendar and Cldr.Calendar behaviours.","ref":"Cldr.Calendar.html#t:calendar/0","title":"Cldr.Calendar.calendar/0","type":"type"},{"doc":"Specifies the type of a calendar","ref":"Cldr.Calendar.html#t:calendar_type/0","title":"Cldr.Calendar.calendar_type/0","type":"type"},{"doc":"Specifies the days of the week as integers. Days of the week are encoded as the integers 1 through 7 with 1 representig Monday and 7 representing Sunday. Note that a calendar can be configured to start on any day of the week. day_of_week is only a way of encoding the days as an integer.","ref":"Cldr.Calendar.html#t:day_of_week/0","title":"Cldr.Calendar.day_of_week/0","type":"type"},{"doc":"The types of relationship between two Date.Range intervals","ref":"Cldr.Calendar.html#t:interval_relation/0","title":"Cldr.Calendar.interval_relation/0","type":"type"},{"doc":"Represents the number of days since the calendar epoch. The Calendar epoch is 0000-01-01 in the proleptic gregorian calendar.","ref":"Cldr.Calendar.html#t:iso_day_number/0","title":"Cldr.Calendar.iso_day_number/0","type":"type"},{"doc":"Boolean indicating is this is a leap month","ref":"Cldr.Calendar.html#t:leap_month?/0","title":"Cldr.Calendar.leap_month?/0","type":"type"},{"doc":"The precision for date intervals","ref":"Cldr.Calendar.html#t:precision/0","title":"Cldr.Calendar.precision/0","type":"type"},{"doc":"Specifies the quarter of year for a calendar date.","ref":"Cldr.Calendar.html#t:quarter/0","title":"Cldr.Calendar.quarter/0","type":"type"},{"doc":"Specifies the week of year for a calendar date.","ref":"Cldr.Calendar.html#t:week/0","title":"Cldr.Calendar.week/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Behaviour.html","title":"Cldr.Calendar.Behaviour","type":"module"},{"doc":"Defines the configuration for a calendar. See Cldr.Calendar.new/3 for usage details.","ref":"Cldr.Calendar.Config.html","title":"Cldr.Calendar.Config","type":"module"},{"doc":"","ref":"Cldr.Calendar.Config.html#first_day_for_locale/2","title":"Cldr.Calendar.Config.first_day_for_locale/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.Config.html#min_days_for_locale/2","title":"Cldr.Calendar.Config.min_days_for_locale/2","type":"function"},{"doc":"Defines the struct type for a calendar configuration","ref":"Cldr.Calendar.Config.html#t:t/0","title":"Cldr.Calendar.Config.t/0","type":"type"},{"doc":"Functions to create and format a difference between two dates, times or datetimes. The difference between two dates (or times or datetimes) is usually defined in terms of days or seconds. A duration is calculated as the difference in time in calendar units: years, months, days, hours, minutes, seconds and microseconds. This is useful to support formatting a string for users in easy-to-understand terms. For example 11 months, 3 days and 4 minutes is a lot easier to understand than 28771440 seconds. The package ex_cldr_units can be optionally configured to provide localized formatting of durations. If configured, the following providers should be configured in the appropriate CLDR backend module. For example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;ja&quot; ] , providers : [ Cldr.Calendar , Cldr.Number , Cldr.Unit , Cldr.List ] end","ref":"Cldr.Calendar.Duration.html","title":"Cldr.Calendar.Duration","type":"module"},{"doc":"Calculates the calendar difference in a Date.Range or CalendarInterval returning a Duration struct. The difference calculated is in terms of years, months, days, hours, minutes, seconds and microseconds. Arguments interval is either Date.Range.t() or a CalendarInterval.t() Returns A {:ok, duration} tuple or a {:error, {exception, reason}} tuple Notes CalendarInterval is defined by the most wonderful calendar_interval library. Example iex&gt; Cldr.Calendar.Duration . new ( Date . range ( ~D[2019-01-01] , ~D[2019-12-31] ) ) { :ok , % Cldr.Calendar.Duration { year : 0 , month : 11 , day : 30 , hour : 0 , microsecond : 0 , minute : 0 , second : 0 } }","ref":"Cldr.Calendar.Duration.html#new/1","title":"Cldr.Calendar.Duration.new/1","type":"function"},{"doc":"Calculates the calendar difference between two dates returning a Duration struct. The difference calculated is in terms of years, months, days, hours, minutes, seconds and microseconds. Arguments from is a date, time or datetime representing the start of the duration. to is a date, time or datetime representing the end of the duration Notes from must be before or at the same time as to . In addition, both from and to must be in the same calendar If from and to are datetime s then they must both be in the same time zone Returns A {:ok, duration} tuple or a {:error, {exception, reason}} tuple Example iex&gt; Cldr.Calendar.Duration . new ( ~D[2019-01-01] , ~D[2019-12-31] ) { :ok , % Cldr.Calendar.Duration { year : 0 , month : 11 , day : 30 , hour : 0 , microsecond : 0 , minute : 0 , second : 0 } }","ref":"Cldr.Calendar.Duration.html#new/2","title":"Cldr.Calendar.Duration.new/2","type":"function"},{"doc":"Calculates the calendar difference in a Date.Range or CalendarInterval returning a Duration struct. The difference calculated is in terms of years, months, days, hours, minutes, seconds and microseconds. Arguments interval is either Date.Range.t() or a CalendarInterval.t() Returns A duration struct or raises an exception Notes CalendarInterval is defined by the most wonderful calendar_interval library. Example iex&gt; Cldr.Calendar.Duration . new! ( Date . range ( ~D[2019-01-01] , ~D[2019-12-31] ) ) % Cldr.Calendar.Duration { year : 0 , month : 11 , day : 30 , hour : 0 , microsecond : 0 , minute : 0 , second : 0 }","ref":"Cldr.Calendar.Duration.html#new!/1","title":"Cldr.Calendar.Duration.new!/1","type":"function"},{"doc":"Calculates the calendar difference between two dates returning a Duration struct. The difference calculated is in terms of years, months, days, hours, minutes, seconds and microseconds. Arguments from is a date, time or datetime representing the start of the duration to is a date, time or datetime representing the end of the duration Note that from must be before or at the same time as to . In addition, both from and to must be in the same calendar. Returns A duration struct or raises an exception Example iex&gt; Cldr.Calendar.Duration . new! ( ~D[2019-01-01] , ~D[2019-12-31] ) % Cldr.Calendar.Duration { year : 0 , month : 11 , day : 30 , hour : 0 , microsecond : 0 , minute : 0 , second : 0 }","ref":"Cldr.Calendar.Duration.html#new!/2","title":"Cldr.Calendar.Duration.new!/2","type":"function"},{"doc":"Returns a string formatted representation of a duration. Note that time units that are zero are ommitted from the output. Formatting is Arguments duration is a duration of type t() returned by Cldr.Calendar.Duration.new/2 options is a Keyword list of options Options :except is a list of time units to be omitted from the formatted output. It may be useful to use except: [:microsecond] for example. The default is [] . locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 The default is Cldr.get_locale/0 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 :list_options is a list of options passed to Cldr.List.to_string/3 to control the final list output. Any other options are passed to Cldr.Number.to_string/3 and Cldr.Unit.to_string/3 during the formatting process. Note Any duration parts that are 0 are not output. Example iex&gt; { :ok , duration } = Cldr.Calendar.Duration . new ( ~D[2019-01-01] , ~D[2019-12-31] ) iex&gt; Cldr.Calendar.Duration . to_string ( duration ) { :ok , &quot;11 months and 30 days&quot; }","ref":"Cldr.Calendar.Duration.html#to_string/2","title":"Cldr.Calendar.Duration.to_string/2","type":"function"},{"doc":"Formats a duration as a string or raises an exception on error. Arguments duration is a duration of type t() returned by Cldr.Calendar.Duration.new/2 options is a Keyword list of options Options See Cldr.Calendar.Duration.to_string/2 Returns A formatted string or raises an exception","ref":"Cldr.Calendar.Duration.html#to_string!/2","title":"Cldr.Calendar.Duration.to_string!/2","type":"function"},{"doc":"A date, time, naivedatetime or datetime","ref":"Cldr.Calendar.Duration.html#t:date_or_time_or_datetime/0","title":"Cldr.Calendar.Duration.date_or_time_or_datetime/0","type":"type"},{"doc":"A interval as either Date.Range.t() CalendarInterval.t()","ref":"Cldr.Calendar.Duration.html#t:interval/0","title":"Cldr.Calendar.Duration.interval/0","type":"type"},{"doc":"Duration in calendar units","ref":"Cldr.Calendar.Duration.html#t:t/0","title":"Cldr.Calendar.Duration.t/0","type":"type"},{"doc":"Encapsulates the era information for known CLDR calendars. The era data in CLDR is presented in different calendars at different times. The current best understanding is: Japanese Calendar From Taisho (1912), the date is Gregorian year, month and day. For Tenshō (Momoyama period) to Meji era (1868) inclusive its Gregorian year but lunar month and day. For earlier eras it is Julian year with lunar month and day (but the Julian and Gregorian years coincide; there are no era dates where the Gregorian year would be different to the Julian year). Other Calendars For Chinese and Korean (dangi) the era dates are Gregorian year with lunar month and lunar day For Coptic, Ethiopic and Islamic calendars the eras are Julian dates (Julian day, month and year). Persian era is Julian year with persian month and day. Gregorian is, well, Gregorian date.","ref":"Cldr.Calendar.Era.html","title":"Cldr.Calendar.Era","type":"module"},{"doc":"Return the era module for a given cldr calendar type.","ref":"Cldr.Calendar.Era.html#era_module/1","title":"Cldr.Calendar.Era.era_module/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.FiscalYear.html","title":"Cldr.Calendar.FiscalYear","type":"module"},{"doc":"","ref":"Cldr.Calendar.FiscalYear.html#calendar_for/1","title":"Cldr.Calendar.FiscalYear.calendar_for/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_calendars/0","title":"Cldr.Calendar.FiscalYear.known_fiscal_calendars/0","type":"function"},{"doc":"","ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_years/0","title":"Cldr.Calendar.FiscalYear.known_fiscal_years/0","type":"function"},{"doc":"Implements the proleptic Gregorian calendar. Intended to be plug-compatible with Calendar.ISO with additional functions to support localisation, date ranges for year , quarter , month and week . When calling Cldr.Calendar.localize/3 on a Calendar.ISO -based date, those dates are first moved to this calendar acting as a localisation proxy.","ref":"Cldr.Calendar.Gregorian.html","title":"Cldr.Calendar.Gregorian","type":"module"},{"doc":"Adds :year , :quarter , :month , :week increments These functions support CalendarInterval","ref":"Cldr.Calendar.Gregorian.html#add/9","title":"Cldr.Calendar.Gregorian.add/9","type":"function"},{"doc":"Identifies that the calendar is month based.","ref":"Cldr.Calendar.Gregorian.html#calendar_base/0","title":"Cldr.Calendar.Gregorian.calendar_base/0","type":"function"},{"doc":"Returns the calendar year as displayed on rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#calendar_year/3","title":"Cldr.Calendar.Gregorian.calendar_year/3","type":"function"},{"doc":"Defines the CLDR calendar type for this calendar. This type is used in support of Cldr.Calendar.localize/3 . Currently only :gregorian is supported.","ref":"Cldr.Calendar.Gregorian.html#cldr_calendar_type/0","title":"Cldr.Calendar.Gregorian.cldr_calendar_type/0","type":"function"},{"doc":"Returns the cyclic year as displayed on rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#cyclic_year/3","title":"Cldr.Calendar.Gregorian.cyclic_year/3","type":"function"},{"doc":"Returns {year, month, day} calculated from the number of iso_days .","ref":"Cldr.Calendar.Gregorian.html#date_from_iso_days/1","title":"Cldr.Calendar.Gregorian.date_from_iso_days/1","type":"function"},{"doc":"Returns the number of days since the calendar epoch for a given year-month-day","ref":"Cldr.Calendar.Gregorian.html#date_to_iso_days/3","title":"Cldr.Calendar.Gregorian.date_to_iso_days/3","type":"function"},{"doc":"Calculates the day and era from the given year , month , and day .","ref":"Cldr.Calendar.Gregorian.html#day_of_era/3","title":"Cldr.Calendar.Gregorian.day_of_era/3","type":"function"},{"doc":"Calculates the day of the week from the given year , month , and day . It is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.Gregorian.html#day_of_week/4","title":"Cldr.Calendar.Gregorian.day_of_week/4","type":"function"},{"doc":"Calculates the day of the year from the given year , month , and day .","ref":"Cldr.Calendar.Gregorian.html#day_of_year/3","title":"Cldr.Calendar.Gregorian.day_of_year/3","type":"function"},{"doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.Gregorian.html#days_in_month/2","title":"Cldr.Calendar.Gregorian.days_in_month/2","type":"function"},{"doc":"Returns the number days in a week.","ref":"Cldr.Calendar.Gregorian.html#days_in_week/0","title":"Cldr.Calendar.Gregorian.days_in_week/0","type":"function"},{"doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.Gregorian.html#days_in_year/1","title":"Cldr.Calendar.Gregorian.days_in_year/1","type":"function"},{"doc":"Returns the extended year as displayed on rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#extended_year/3","title":"Cldr.Calendar.Gregorian.extended_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the first day of the given year for this calendar.","ref":"Cldr.Calendar.Gregorian.html#first_gregorian_day_of_year/1","title":"Cldr.Calendar.Gregorian.first_gregorian_day_of_year/1","type":"function"},{"doc":"Calculates the ISO week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.Gregorian.html#iso_week_of_year/3","title":"Cldr.Calendar.Gregorian.iso_week_of_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the last day of the given year for this calendar.","ref":"Cldr.Calendar.Gregorian.html#last_gregorian_day_of_year/1","title":"Cldr.Calendar.Gregorian.last_gregorian_day_of_year/1","type":"function"},{"doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.Gregorian.html#leap_year?/1","title":"Cldr.Calendar.Gregorian.leap_year?/1","type":"function"},{"doc":"Returns a t:Date.Range representing a given month of a year.","ref":"Cldr.Calendar.Gregorian.html#month/2","title":"Cldr.Calendar.Gregorian.month/2","type":"function"},{"doc":"Calculates the month of the year from the given year , month , and day . It is an integer from 1 to 12.","ref":"Cldr.Calendar.Gregorian.html#month_of_year/3","title":"Cldr.Calendar.Gregorian.month_of_year/3","type":"function"},{"doc":"Converts the t:Calendar.iso_days format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.Gregorian.html#naive_datetime_from_iso_days/1","title":"Cldr.Calendar.Gregorian.naive_datetime_from_iso_days/1","type":"function"},{"doc":"Returns the t:Calendar.iso_days format of the specified date.","ref":"Cldr.Calendar.Gregorian.html#naive_datetime_to_iso_days/7","title":"Cldr.Calendar.Gregorian.naive_datetime_to_iso_days/7","type":"function"},{"doc":"Calculates the number of period in a given year . A period corresponds to a month in month-based calendars and a week in week-based calendars.","ref":"Cldr.Calendar.Gregorian.html#periods_in_year/1","title":"Cldr.Calendar.Gregorian.periods_in_year/1","type":"function"},{"doc":"Adds an increment number of date_part s to a year-month-day . date_part can be :years , :quarters or :months .","ref":"Cldr.Calendar.Gregorian.html#plus/6","title":"Cldr.Calendar.Gregorian.plus/6","type":"function"},{"doc":"Returns a t:Date.Range representing a given quarter of a year.","ref":"Cldr.Calendar.Gregorian.html#quarter/2","title":"Cldr.Calendar.Gregorian.quarter/2","type":"function"},{"doc":"Calculates the quarter of the year from the given year , month , and day . It is an integer from 1 to 4.","ref":"Cldr.Calendar.Gregorian.html#quarter_of_year/3","title":"Cldr.Calendar.Gregorian.quarter_of_year/3","type":"function"},{"doc":"Returns the related gregorain year as displayed on rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#related_gregorian_year/3","title":"Cldr.Calendar.Gregorian.related_gregorian_year/3","type":"function"},{"doc":"Determines if the date given is valid according to this calendar.","ref":"Cldr.Calendar.Gregorian.html#valid_date?/3","title":"Cldr.Calendar.Gregorian.valid_date?/3","type":"function"},{"doc":"Returns a t:Date.Range representing a given week of a year.","ref":"Cldr.Calendar.Gregorian.html#week/2","title":"Cldr.Calendar.Gregorian.week/2","type":"function"},{"doc":"Calculates the week of the month from the given year , month , and day . It is an integer from 1 to 5.","ref":"Cldr.Calendar.Gregorian.html#week_of_month/3","title":"Cldr.Calendar.Gregorian.week_of_month/3","type":"function"},{"doc":"Calculates the week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.Gregorian.html#week_of_year/3","title":"Cldr.Calendar.Gregorian.week_of_year/3","type":"function"},{"doc":"Returns the number weeks in a given year.","ref":"Cldr.Calendar.Gregorian.html#weeks_in_year/1","title":"Cldr.Calendar.Gregorian.weeks_in_year/1","type":"function"},{"doc":"Returns a t:Date.Range representing a given year.","ref":"Cldr.Calendar.Gregorian.html#year/1","title":"Cldr.Calendar.Gregorian.year/1","type":"function"},{"doc":"Calculates the year and era from the given year . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.Gregorian.html#year_of_era/1","title":"Cldr.Calendar.Gregorian.year_of_era/1","type":"function"},{"doc":"Calculates the year and era from the given year , month and day . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.Gregorian.html#year_of_era/3","title":"Cldr.Calendar.Gregorian.year_of_era/3","type":"function"},{"doc":"","ref":"Cldr.Calendar.Gregorian.html#t:day/0","title":"Cldr.Calendar.Gregorian.day/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Gregorian.html#t:month/0","title":"Cldr.Calendar.Gregorian.month/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Gregorian.html#t:year/0","title":"Cldr.Calendar.Gregorian.year/0","type":"type"},{"doc":"Implements the ISO Week calendar. The ISO Week calendar manages dates in a yyyy-ww-dd format with each year having either 52 or 53 weeks.","ref":"Cldr.Calendar.ISOWeek.html","title":"Cldr.Calendar.ISOWeek","type":"module"},{"doc":"Adds a :year, :month, :day or time increments These functions support CalendarInterval","ref":"Cldr.Calendar.ISOWeek.html#add/9","title":"Cldr.Calendar.ISOWeek.add/9","type":"function"},{"doc":"Identifies that the calendar is week based.","ref":"Cldr.Calendar.ISOWeek.html#calendar_base/0","title":"Cldr.Calendar.ISOWeek.calendar_base/0","type":"function"},{"doc":"Returns the calendar year as displayed on rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#calendar_year/3","title":"Cldr.Calendar.ISOWeek.calendar_year/3","type":"function"},{"doc":"Defines the CLDR calendar type for this calendar. This type is used in support of Cldr.Calendar.localize/3 . Currently only :gregorian is supported.","ref":"Cldr.Calendar.ISOWeek.html#cldr_calendar_type/0","title":"Cldr.Calendar.ISOWeek.cldr_calendar_type/0","type":"function"},{"doc":"Returns the cyclic year as displayed on rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#cyclic_year/3","title":"Cldr.Calendar.ISOWeek.cyclic_year/3","type":"function"},{"doc":"Returns {year, month, day} calculated from the number of iso_days .","ref":"Cldr.Calendar.ISOWeek.html#date_from_iso_days/1","title":"Cldr.Calendar.ISOWeek.date_from_iso_days/1","type":"function"},{"doc":"Returns the number of days since the calendar epoch for a given year-month-day","ref":"Cldr.Calendar.ISOWeek.html#date_to_iso_days/3","title":"Cldr.Calendar.ISOWeek.date_to_iso_days/3","type":"function"},{"doc":"Calculates the day and era from the given year , month , and day .","ref":"Cldr.Calendar.ISOWeek.html#day_of_era/3","title":"Cldr.Calendar.ISOWeek.day_of_era/3","type":"function"},{"doc":"Calculates the day of the week from the given year , month , and day . It is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.ISOWeek.html#day_of_week/4","title":"Cldr.Calendar.ISOWeek.day_of_week/4","type":"function"},{"doc":"Calculates the day of the year from the given year , month , and day . It is an integer from 1 to 366.","ref":"Cldr.Calendar.ISOWeek.html#day_of_year/3","title":"Cldr.Calendar.ISOWeek.day_of_year/3","type":"function"},{"doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.ISOWeek.html#days_in_month/2","title":"Cldr.Calendar.ISOWeek.days_in_month/2","type":"function"},{"doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.ISOWeek.html#days_in_week/0","title":"Cldr.Calendar.ISOWeek.days_in_week/0","type":"function"},{"doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.ISOWeek.html#days_in_year/1","title":"Cldr.Calendar.ISOWeek.days_in_year/1","type":"function"},{"doc":"Returns the extended year as displayed on rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#extended_year/3","title":"Cldr.Calendar.ISOWeek.extended_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the first day of the given year for this calendar.","ref":"Cldr.Calendar.ISOWeek.html#first_gregorian_day_of_year/1","title":"Cldr.Calendar.ISOWeek.first_gregorian_day_of_year/1","type":"function"},{"doc":"Calculates the ISO week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.ISOWeek.html#iso_week_of_year/3","title":"Cldr.Calendar.ISOWeek.iso_week_of_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the last day of the given year for this calendar.","ref":"Cldr.Calendar.ISOWeek.html#last_gregorian_day_of_year/1","title":"Cldr.Calendar.ISOWeek.last_gregorian_day_of_year/1","type":"function"},{"doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.ISOWeek.html#leap_year?/1","title":"Cldr.Calendar.ISOWeek.leap_year?/1","type":"function"},{"doc":"Returns a Date.Range.t representing a given month of a year.","ref":"Cldr.Calendar.ISOWeek.html#month/2","title":"Cldr.Calendar.ISOWeek.month/2","type":"function"},{"doc":"Calculates the month of the year from the given year , month , and day . It is an integer from 1 to 12.","ref":"Cldr.Calendar.ISOWeek.html#month_of_year/3","title":"Cldr.Calendar.ISOWeek.month_of_year/3","type":"function"},{"doc":"Converts the Calendar.iso_days/0 format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.ISOWeek.html#naive_datetime_from_iso_days/1","title":"Cldr.Calendar.ISOWeek.naive_datetime_from_iso_days/1","type":"function"},{"doc":"Returns the Calendar.iso_days/0 format of the specified date.","ref":"Cldr.Calendar.ISOWeek.html#naive_datetime_to_iso_days/7","title":"Cldr.Calendar.ISOWeek.naive_datetime_to_iso_days/7","type":"function"},{"doc":"Calculates the number of period in a given year . A period corresponds to a month in month-based calendars and a week in week-based calendars..","ref":"Cldr.Calendar.ISOWeek.html#periods_in_year/1","title":"Cldr.Calendar.ISOWeek.periods_in_year/1","type":"function"},{"doc":"Adds an increment number of date_part s to a year-month-day . date_part can be :years , :quarters , or :months .","ref":"Cldr.Calendar.ISOWeek.html#plus/6","title":"Cldr.Calendar.ISOWeek.plus/6","type":"function"},{"doc":"Returns a Date.Range.t representing a given quarter of a year.","ref":"Cldr.Calendar.ISOWeek.html#quarter/2","title":"Cldr.Calendar.ISOWeek.quarter/2","type":"function"},{"doc":"Calculates the quarter of the year from the given year , month , and day . It is an integer from 1 to 4.","ref":"Cldr.Calendar.ISOWeek.html#quarter_of_year/3","title":"Cldr.Calendar.ISOWeek.quarter_of_year/3","type":"function"},{"doc":"Returns the related gregorian year as displayed on rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#related_gregorian_year/3","title":"Cldr.Calendar.ISOWeek.related_gregorian_year/3","type":"function"},{"doc":"Determines if the date given is valid according to the this calendar.","ref":"Cldr.Calendar.ISOWeek.html#valid_date?/3","title":"Cldr.Calendar.ISOWeek.valid_date?/3","type":"function"},{"doc":"Returns a Date.Range.t representing a given week of a year.","ref":"Cldr.Calendar.ISOWeek.html#week/2","title":"Cldr.Calendar.ISOWeek.week/2","type":"function"},{"doc":"Calculates the week of the month from the given year , month , and day . It is an integer from 1 to 5.","ref":"Cldr.Calendar.ISOWeek.html#week_of_month/3","title":"Cldr.Calendar.ISOWeek.week_of_month/3","type":"function"},{"doc":"Calculates the week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.ISOWeek.html#week_of_year/3","title":"Cldr.Calendar.ISOWeek.week_of_year/3","type":"function"},{"doc":"Returns the number weeks in a given year.","ref":"Cldr.Calendar.ISOWeek.html#weeks_in_year/1","title":"Cldr.Calendar.ISOWeek.weeks_in_year/1","type":"function"},{"doc":"Returns a Date.Range.t representing a given year.","ref":"Cldr.Calendar.ISOWeek.html#year/1","title":"Cldr.Calendar.ISOWeek.year/1","type":"function"},{"doc":"Calculates the year and era from the given year . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.ISOWeek.html#year_of_era/1","title":"Cldr.Calendar.ISOWeek.year_of_era/1","type":"function"},{"doc":"Calculates the year and era from the given year , month and day . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.ISOWeek.html#year_of_era/3","title":"Cldr.Calendar.ISOWeek.year_of_era/3","type":"function"},{"doc":"","ref":"Cldr.Calendar.ISOWeek.html#t:day/0","title":"Cldr.Calendar.ISOWeek.day/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.ISOWeek.html#t:month/0","title":"Cldr.Calendar.ISOWeek.month/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.ISOWeek.html#t:week/0","title":"Cldr.Calendar.ISOWeek.week/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.ISOWeek.html#t:year/0","title":"Cldr.Calendar.ISOWeek.year/0","type":"type"},{"doc":"Implements functions to return intervals and compare date intervals. In particular it provides functions which return an interval (as a Date.Range.t ) for years, quarters, months, weeks and days. In general, the intervals created with the packaage calendar_interval are to be preferred since they can used over different time precisions whereas the functions in this module are all intervals of a day. In order to be used with ex_cldr_calendars , version &quot;~&gt; 0.2&quot; of calendar_interval is required. Note however that as of release 0.2 , calendar_interval does not support intervals of quarters or weeks .","ref":"Cldr.Calendar.Interval.html","title":"Cldr.Calendar.Interval","type":"module"},{"doc":"Compare two date ranges. Uses Allen's Interval Algebra to return one of 13 different relationships: Relation Converse :precedes :preceded_by :meets :met_by :overlaps :overlapped_by :finished_by :finishes :contains :during :starts :started_by :equals :equals Arguments range_1 is a Date.Range.t range_2 is a Date.Range.t Returns An atom representing the relationship between the two ranges. Examples iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) :meets iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-03] ) :precedes iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-03] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) :preceded_by iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) :met_by iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) :equals","ref":"Cldr.Calendar.Interval.html#compare/2","title":"Cldr.Calendar.Interval.compare/2","type":"function"},{"doc":"Returns a Date.Range.t that represents the day . The range is enumerable. Arguments year is any year for calendar day is any day in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian . Returns A Date.Range.t() representing the the enumerable days in the week Examples iex&gt; Cldr.Calendar.Interval . day 2019 , 52 , Cldr.Calendar.Fiscal.US # DateRange &lt; ~D[2019-02-21 Cldr.Calendar.Fiscal.US] , ~D[2019-02-21 Cldr.Calendar.Fiscal.US] &gt; iex&gt; Cldr.Calendar.Interval . day 2019 , 92 , Cldr.Calendar.NRF # DateRange &lt; ~D[2019-W14-1 Cldr.Calendar.NRF] , ~D[2019-W14-1 Cldr.Calendar.NRF] &gt; Cldr.Calendar.Interval . day 2019 , 8 , Cldr.Calendar.ISOWeek # DateRange &lt; % Date { calendar : Cldr.Calendar.ISOWeek , day : 1 , month : 2 , year : 2019 } , % Date { calendar : Cldr.Calendar.ISOWeek , day : 1 , month : 2 , year : 2019 } &gt;","ref":"Cldr.Calendar.Interval.html#day/1","title":"Cldr.Calendar.Interval.day/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Interval.html#day/3","title":"Cldr.Calendar.Interval.day/3","type":"function"},{"doc":"Returns a Date.Range.t that represents the year . The range is enumerable. Arguments year is any year for calendar month is any month in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian . Returns A Date.Range.t() representing the the enumerable days in the month Examples iex&gt; Cldr.Calendar.Interval . month 2019 , 3 , Cldr.Calendar.Fiscal.UK # DateRange &lt; ~D[2019-03-01 Cldr.Calendar.Fiscal.UK] , ~D[2019-03-30 Cldr.Calendar.Fiscal.UK] &gt; iex&gt; Cldr.Calendar.Interval . month 2019 , 3 , Cldr.Calendar.Fiscal.US # DateRange &lt; ~D[2019-03-01 Cldr.Calendar.Fiscal.US] , ~D[2019-03-31 Cldr.Calendar.Fiscal.US] &gt;","ref":"Cldr.Calendar.Interval.html#month/1","title":"Cldr.Calendar.Interval.month/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Interval.html#month/3","title":"Cldr.Calendar.Interval.month/3","type":"function"},{"doc":"Returns a Date.Range.t that represents the quarter . The range is enumerable. Arguments year is any year for calendar quarter is any quarter in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian . Returns A Date.Range.t() representing the the enumerable days in the quarter Examples iex&gt; Cldr.Calendar.Interval . quarter 2019 , 2 , Cldr.Calendar.Fiscal.UK # DateRange &lt; ~D[2019-04-01 Cldr.Calendar.Fiscal.UK] , ~D[2019-06-30 Cldr.Calendar.Fiscal.UK] &gt; iex&gt; Cldr.Calendar.Interval . quarter 2019 , 2 , Cldr.Calendar.ISOWeek # DateRange &lt; ~D[2019-W14-1 Cldr.Calendar.ISOWeek] , ~D[2019-W26-7 Cldr.Calendar.ISOWeek] &gt;","ref":"Cldr.Calendar.Interval.html#quarter/1","title":"Cldr.Calendar.Interval.quarter/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Interval.html#quarter/3","title":"Cldr.Calendar.Interval.quarter/3","type":"function"},{"doc":"Returns a Date.Range.t that represents the year . The range is enumerable. Arguments year is any year for calendar week is any week in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian . Returns A Date.Range.t() representing the the enumerable days in the week or {:error, :not_defined} if the calendar does not support the concept of weeks Examples iex&gt; Cldr.Calendar.Interval . week 2019 , 52 , Cldr.Calendar.Fiscal.US # DateRange &lt; ~D[2019-12-22 Cldr.Calendar.Fiscal.US] , ~D[2019-12-28 Cldr.Calendar.Fiscal.US] &gt; iex&gt; Cldr.Calendar.Interval . week 2019 , 52 , Cldr.Calendar.NRF # DateRange &lt; ~D[2019-W52-1 Cldr.Calendar.NRF] , ~D[2019-W52-7 Cldr.Calendar.NRF] &gt; iex&gt; Cldr.Calendar.Interval . week 2019 , 52 , Cldr.Calendar.ISOWeek # DateRange &lt; ~D[2019-W52-1 Cldr.Calendar.ISOWeek] , ~D[2019-W52-7 Cldr.Calendar.ISOWeek] &gt; iex&gt; Cldr.Calendar.Interval . week 2019 , 52 , Cldr.Calendar.Julian { :error , :not_defined }","ref":"Cldr.Calendar.Interval.html#week/1","title":"Cldr.Calendar.Interval.week/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Interval.html#week/3","title":"Cldr.Calendar.Interval.week/3","type":"function"},{"doc":"Returns a Date.Range.t that represents the year . The range is enumerable. Arguments year is any year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian . Returns A Date.Range.t() representing the the enumerable days in the year Examples iex&gt; Cldr.Calendar.Interval . year 2019 , Cldr.Calendar.Fiscal.UK # DateRange &lt; ~D[2019-01-01 Cldr.Calendar.Fiscal.UK] , ~D[2019-12-31 Cldr.Calendar.Fiscal.UK] &gt; iex&gt; Cldr.Calendar.Interval . year 2019 , Cldr.Calendar.NRF # DateRange &lt; ~D[2019-W01-1 Cldr.Calendar.NRF] , ~D[2019-W52-7 Cldr.Calendar.NRF] &gt;","ref":"Cldr.Calendar.Interval.html#year/1","title":"Cldr.Calendar.Interval.year/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Interval.html#year/2","title":"Cldr.Calendar.Interval.year/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.Julian.html","title":"Cldr.Calendar.Julian","type":"module"},{"doc":"Identifies that this calendar is month based.","ref":"Cldr.Calendar.Julian.html#calendar_base/0","title":"Cldr.Calendar.Julian.calendar_base/0","type":"function"},{"doc":"Returns the calendar year as displayed on rendered calendars.","ref":"Cldr.Calendar.Julian.html#calendar_year/3","title":"Cldr.Calendar.Julian.calendar_year/3","type":"function"},{"doc":"Defines the CLDR calendar type for this calendar. This type is used in support of Cldr.Calendar.localize/3 . Currently only :gregorian is supported.","ref":"Cldr.Calendar.Julian.html#cldr_calendar_type/0","title":"Cldr.Calendar.Julian.cldr_calendar_type/0","type":"function"},{"doc":"Returns the cyclic year as displayed on rendered calendars.","ref":"Cldr.Calendar.Julian.html#cyclic_year/3","title":"Cldr.Calendar.Julian.cyclic_year/3","type":"function"},{"doc":"Returns a {year, month, day} calculated from the number of iso_days .","ref":"Cldr.Calendar.Julian.html#date_from_iso_days/1","title":"Cldr.Calendar.Julian.date_from_iso_days/1","type":"function"},{"doc":"Returns the number of days since the calendar epoch for a given year-month-day","ref":"Cldr.Calendar.Julian.html#date_to_iso_days/3","title":"Cldr.Calendar.Julian.date_to_iso_days/3","type":"function"},{"doc":"Calculates the day and era from the given year , month , and day .","ref":"Cldr.Calendar.Julian.html#day_of_era/3","title":"Cldr.Calendar.Julian.day_of_era/3","type":"function"},{"doc":"Calculates the day of the week from the given year , month , and day . It is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.Julian.html#day_of_week/4","title":"Cldr.Calendar.Julian.day_of_week/4","type":"function"},{"doc":"Calculates the day of the year from the given year , month , and day .","ref":"Cldr.Calendar.Julian.html#day_of_year/3","title":"Cldr.Calendar.Julian.day_of_year/3","type":"function"},{"doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.Julian.html#days_in_month/2","title":"Cldr.Calendar.Julian.days_in_month/2","type":"function"},{"doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.Julian.html#days_in_week/0","title":"Cldr.Calendar.Julian.days_in_week/0","type":"function"},{"doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.Julian.html#days_in_year/1","title":"Cldr.Calendar.Julian.days_in_year/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Julian.html#epoch/0","title":"Cldr.Calendar.Julian.epoch/0","type":"function"},{"doc":"Returns the extended year as displayed on rendered calendars.","ref":"Cldr.Calendar.Julian.html#extended_year/3","title":"Cldr.Calendar.Julian.extended_year/3","type":"function"},{"doc":"Calculates the ISO week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#iso_week_of_year/3","title":"Cldr.Calendar.Julian.iso_week_of_year/3","type":"function"},{"doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.Julian.html#leap_year?/1","title":"Cldr.Calendar.Julian.leap_year?/1","type":"function"},{"doc":"Returns a Date.Range.t representing a given month of a year.","ref":"Cldr.Calendar.Julian.html#month/2","title":"Cldr.Calendar.Julian.month/2","type":"function"},{"doc":"Calculates the month of the year from the given year , month , and day . It is an integer from 1 to 12.","ref":"Cldr.Calendar.Julian.html#month_of_year/3","title":"Cldr.Calendar.Julian.month_of_year/3","type":"function"},{"doc":"Converts the Calendar.iso_days/0 format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.Julian.html#naive_datetime_from_iso_days/1","title":"Cldr.Calendar.Julian.naive_datetime_from_iso_days/1","type":"function"},{"doc":"Returns the Calendar.iso_days/0 format of the specified date.","ref":"Cldr.Calendar.Julian.html#naive_datetime_to_iso_days/7","title":"Cldr.Calendar.Julian.naive_datetime_to_iso_days/7","type":"function"},{"doc":"Calculates the number of period in a given year . A period corresponds to a month in month-based calendars and a week in week-based calendars..","ref":"Cldr.Calendar.Julian.html#periods_in_year/1","title":"Cldr.Calendar.Julian.periods_in_year/1","type":"function"},{"doc":"Adds an increment number of date_part s to a year-month-day . date_part can be :quarters or :months .","ref":"Cldr.Calendar.Julian.html#plus/6","title":"Cldr.Calendar.Julian.plus/6","type":"function"},{"doc":"Returns a Date.Range.t representing a given quarter of a year.","ref":"Cldr.Calendar.Julian.html#quarter/2","title":"Cldr.Calendar.Julian.quarter/2","type":"function"},{"doc":"Calculates the quarter of the year from the given year , month , and day . It is an integer from 1 to 4.","ref":"Cldr.Calendar.Julian.html#quarter_of_year/3","title":"Cldr.Calendar.Julian.quarter_of_year/3","type":"function"},{"doc":"Returns the related gregorian year as displayed on rendered calendars.","ref":"Cldr.Calendar.Julian.html#related_gregorian_year/3","title":"Cldr.Calendar.Julian.related_gregorian_year/3","type":"function"},{"doc":"Determines if the date given is valid according to this calendar.","ref":"Cldr.Calendar.Julian.html#valid_date?/3","title":"Cldr.Calendar.Julian.valid_date?/3","type":"function"},{"doc":"Returns a Date.Range.t representing a given week of a year.","ref":"Cldr.Calendar.Julian.html#week/2","title":"Cldr.Calendar.Julian.week/2","type":"function"},{"doc":"Calculates the week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#week_of_month/3","title":"Cldr.Calendar.Julian.week_of_month/3","type":"function"},{"doc":"Calculates the week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#week_of_year/3","title":"Cldr.Calendar.Julian.week_of_year/3","type":"function"},{"doc":"Returns a Date.Range.t representing a given year.","ref":"Cldr.Calendar.Julian.html#year/1","title":"Cldr.Calendar.Julian.year/1","type":"function"},{"doc":"Calculates the year and era from the given year . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.Julian.html#year_of_era/1","title":"Cldr.Calendar.Julian.year_of_era/1","type":"function"},{"doc":"Calculates the year and era from the given year , month and day .","ref":"Cldr.Calendar.Julian.html#year_of_era/3","title":"Cldr.Calendar.Julian.year_of_era/3","type":"function"},{"doc":"","ref":"Cldr.Calendar.Julian.html#t:day/0","title":"Cldr.Calendar.Julian.day/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Julian.html#t:month/0","title":"Cldr.Calendar.Julian.month/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Julian.html#t:year/0","title":"Cldr.Calendar.Julian.year/0","type":"type"},{"doc":"Provide K-Day functions for Dates, DateTimes and NaiveDateTimes.","ref":"Cldr.Calendar.Kday.html","title":"Cldr.Calendar.Kday","type":"module"},{"doc":"Return the date of the first day_of_week on or after the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or ISO days since epoch. k is an integer day of the week. Returns A %Date{”} in the calendar of the date provided as an argument Examples # US election day iex&gt; Cldr.Calendar.Kday . first_kday ( ~D[2017-11-02] , 2 ) ~D[2017-11-07] # US Daylight savings end iex&gt; Cldr.Calendar.Kday . first_kday ( ~D[2017-11-01] , 7 ) ~D[2017-11-05]","ref":"Cldr.Calendar.Kday.html#first_kday/2","title":"Cldr.Calendar.Kday.first_kday/2","type":"function"},{"doc":"Return the date of the day_of_week after the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or ISO days since epoch. k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday . kday_after ( ~D[2016-02-29] , 2 ) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday . kday_after ( ~D[2017-11-30] , 1 ) ~D[2017-12-04] iex&gt; Cldr.Calendar.Kday . kday_after ( ~D[2017-06-30] , 6 ) ~D[2017-07-01] iex&gt; Cldr.Calendar.Kday . kday_after ( ~D[2021-03-28] , 7 ) ~D[2021-04-04]","ref":"Cldr.Calendar.Kday.html#kday_after/2","title":"Cldr.Calendar.Kday.kday_after/2","type":"function"},{"doc":"Return the date of the day_of_week before the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday . kday_before ( ~D[2016-02-29] , 2 ) ~D[2016-02-23] iex&gt; Cldr.Calendar.Kday . kday_before ( ~D[2017-11-30] , 1 ) ~D[2017-11-27] # 6 means Saturday. Use either the integer value or the atom form. iex&gt; Cldr.Calendar.Kday . kday_before ( ~D[2017-06-30] , 6 ) ~D[2017-06-24]","ref":"Cldr.Calendar.Kday.html#kday_before/2","title":"Cldr.Calendar.Kday.kday_before/2","type":"function"},{"doc":"Return the date of the day_of_week nearest the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday . kday_nearest ( ~D[2016-02-29] , 2 ) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday . kday_nearest ( ~D[2017-11-30] , 1 ) ~D[2017-11-27] iex&gt; Cldr.Calendar.Kday . kday_nearest ( ~D[2017-06-30] , 6 ) ~D[2017-07-01]","ref":"Cldr.Calendar.Kday.html#kday_nearest/2","title":"Cldr.Calendar.Kday.kday_nearest/2","type":"function"},{"doc":"Return the date of the day_of_week on or after the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday . kday_on_or_after ( ~D[2016-02-29] , 2 ) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday . kday_on_or_after ( ~D[2017-11-30] , 1 ) ~D[2017-12-04] iex&gt; Cldr.Calendar.Kday . kday_on_or_after ( ~D[2017-06-30] , 6 ) ~D[2017-07-01]","ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2","title":"Cldr.Calendar.Kday.kday_on_or_after/2","type":"function"},{"doc":"Return the date of the day_of_week on or before the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday . kday_on_or_before ( ~D[2016-02-29] , 2 ) ~D[2016-02-23] iex&gt; Cldr.Calendar.Kday . kday_on_or_before ( ~D[2017-11-30] , 1 ) ~D[2017-11-27] iex&gt; Cldr.Calendar.Kday . kday_on_or_before ( ~D[2017-06-30] , 6 ) ~D[2017-06-24]","ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2","title":"Cldr.Calendar.Kday.kday_on_or_before/2","type":"function"},{"doc":"Return the date of the last day_of_week on or before the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or ISO days since epoch. k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Example # Memorial Day in the US iex&gt; Cldr.Calendar.Kday . last_kday ( ~D[2017-05-31] , 1 ) ~D[2017-05-29]","ref":"Cldr.Calendar.Kday.html#last_kday/2","title":"Cldr.Calendar.Kday.last_kday/2","type":"function"},{"doc":"Return the date of the nth day_of_week on or before/after the specified date . Arguments date is %Date{} , a %DateTime{} , %NaiveDateTime{} or ISO days since epoch. n is the cardinal number of k before (negative n ) or after (positive n ) the specified date k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples # Thanksgiving in the US iex&gt; Cldr.Calendar.Kday . nth_kday ( ~D[2017-11-01] , 4 , 4 ) ~D[2017-11-23] # Labor day in the US iex&gt; Cldr.Calendar.Kday . nth_kday ( ~D[2017-09-01] , 1 , 1 ) ~D[2017-09-04] # Daylight savings time starts in the US iex&gt; Cldr.Calendar.Kday . nth_kday ( ~D[2017-03-01] , 2 , 7 ) ~D[2017-03-12]","ref":"Cldr.Calendar.Kday.html#nth_kday/3","title":"Cldr.Calendar.Kday.nth_kday/3","type":"function"},{"doc":"Implements the US National Retail Federation (NRF) calendar. The NRF calendar is defined to end on the last Saturday of January. This week-based approach allows for easier comparison of seasonal business performance with most US seasonal holidays falling into the same week of the year.","ref":"Cldr.Calendar.NRF.html","title":"Cldr.Calendar.NRF","type":"module"},{"doc":"Adds a :year, :month, :day or time increments These functions support CalendarInterval","ref":"Cldr.Calendar.NRF.html#add/9","title":"Cldr.Calendar.NRF.add/9","type":"function"},{"doc":"Identifies that the calendar is week based.","ref":"Cldr.Calendar.NRF.html#calendar_base/0","title":"Cldr.Calendar.NRF.calendar_base/0","type":"function"},{"doc":"Returns the calendar year as displayed on rendered calendars.","ref":"Cldr.Calendar.NRF.html#calendar_year/3","title":"Cldr.Calendar.NRF.calendar_year/3","type":"function"},{"doc":"Defines the CLDR calendar type for this calendar. This type is used in support of Cldr.Calendar.localize/3 . Currently only :gregorian is supported.","ref":"Cldr.Calendar.NRF.html#cldr_calendar_type/0","title":"Cldr.Calendar.NRF.cldr_calendar_type/0","type":"function"},{"doc":"Returns the cyclic year as displayed on rendered calendars.","ref":"Cldr.Calendar.NRF.html#cyclic_year/3","title":"Cldr.Calendar.NRF.cyclic_year/3","type":"function"},{"doc":"Returns {year, month, day} calculated from the number of iso_days .","ref":"Cldr.Calendar.NRF.html#date_from_iso_days/1","title":"Cldr.Calendar.NRF.date_from_iso_days/1","type":"function"},{"doc":"Returns the number of days since the calendar epoch for a given year-month-day","ref":"Cldr.Calendar.NRF.html#date_to_iso_days/3","title":"Cldr.Calendar.NRF.date_to_iso_days/3","type":"function"},{"doc":"Calculates the day and era from the given year , month , and day .","ref":"Cldr.Calendar.NRF.html#day_of_era/3","title":"Cldr.Calendar.NRF.day_of_era/3","type":"function"},{"doc":"Calculates the day of the week from the given year , month , and day . It is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.NRF.html#day_of_week/4","title":"Cldr.Calendar.NRF.day_of_week/4","type":"function"},{"doc":"Calculates the day of the year from the given year , month , and day . It is an integer from 1 to 366.","ref":"Cldr.Calendar.NRF.html#day_of_year/3","title":"Cldr.Calendar.NRF.day_of_year/3","type":"function"},{"doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.NRF.html#days_in_month/2","title":"Cldr.Calendar.NRF.days_in_month/2","type":"function"},{"doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.NRF.html#days_in_week/0","title":"Cldr.Calendar.NRF.days_in_week/0","type":"function"},{"doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.NRF.html#days_in_year/1","title":"Cldr.Calendar.NRF.days_in_year/1","type":"function"},{"doc":"Returns the extended year as displayed on rendered calendars.","ref":"Cldr.Calendar.NRF.html#extended_year/3","title":"Cldr.Calendar.NRF.extended_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the first day of the given year for this calendar.","ref":"Cldr.Calendar.NRF.html#first_gregorian_day_of_year/1","title":"Cldr.Calendar.NRF.first_gregorian_day_of_year/1","type":"function"},{"doc":"Calculates the ISO week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.NRF.html#iso_week_of_year/3","title":"Cldr.Calendar.NRF.iso_week_of_year/3","type":"function"},{"doc":"Returns the number of iso_days that is the last day of the given year for this calendar.","ref":"Cldr.Calendar.NRF.html#last_gregorian_day_of_year/1","title":"Cldr.Calendar.NRF.last_gregorian_day_of_year/1","type":"function"},{"doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.NRF.html#leap_year?/1","title":"Cldr.Calendar.NRF.leap_year?/1","type":"function"},{"doc":"Returns a Date.Range.t representing a given month of a year.","ref":"Cldr.Calendar.NRF.html#month/2","title":"Cldr.Calendar.NRF.month/2","type":"function"},{"doc":"Calculates the month of the year from the given year , month , and day . It is an integer from 1 to 12.","ref":"Cldr.Calendar.NRF.html#month_of_year/3","title":"Cldr.Calendar.NRF.month_of_year/3","type":"function"},{"doc":"Converts the Calendar.iso_days/0 format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.NRF.html#naive_datetime_from_iso_days/1","title":"Cldr.Calendar.NRF.naive_datetime_from_iso_days/1","type":"function"},{"doc":"Returns the Calendar.iso_days/0 format of the specified date.","ref":"Cldr.Calendar.NRF.html#naive_datetime_to_iso_days/7","title":"Cldr.Calendar.NRF.naive_datetime_to_iso_days/7","type":"function"},{"doc":"Calculates the number of period in a given year . A period corresponds to a month in month-based calendars and a week in week-based calendars..","ref":"Cldr.Calendar.NRF.html#periods_in_year/1","title":"Cldr.Calendar.NRF.periods_in_year/1","type":"function"},{"doc":"Adds an increment number of date_part s to a year-month-day . date_part can be :years , :quarters , or :months .","ref":"Cldr.Calendar.NRF.html#plus/6","title":"Cldr.Calendar.NRF.plus/6","type":"function"},{"doc":"Returns a Date.Range.t representing a given quarter of a year.","ref":"Cldr.Calendar.NRF.html#quarter/2","title":"Cldr.Calendar.NRF.quarter/2","type":"function"},{"doc":"Calculates the quarter of the year from the given year , month , and day . It is an integer from 1 to 4.","ref":"Cldr.Calendar.NRF.html#quarter_of_year/3","title":"Cldr.Calendar.NRF.quarter_of_year/3","type":"function"},{"doc":"Returns the related gregorian year as displayed on rendered calendars.","ref":"Cldr.Calendar.NRF.html#related_gregorian_year/3","title":"Cldr.Calendar.NRF.related_gregorian_year/3","type":"function"},{"doc":"Determines if the date given is valid according to the this calendar.","ref":"Cldr.Calendar.NRF.html#valid_date?/3","title":"Cldr.Calendar.NRF.valid_date?/3","type":"function"},{"doc":"Returns a Date.Range.t representing a given week of a year.","ref":"Cldr.Calendar.NRF.html#week/2","title":"Cldr.Calendar.NRF.week/2","type":"function"},{"doc":"Calculates the week of the month from the given year , month , and day . It is an integer from 1 to 5.","ref":"Cldr.Calendar.NRF.html#week_of_month/3","title":"Cldr.Calendar.NRF.week_of_month/3","type":"function"},{"doc":"Calculates the week of the year from the given year , month , and day . It is an integer from 1 to 53.","ref":"Cldr.Calendar.NRF.html#week_of_year/3","title":"Cldr.Calendar.NRF.week_of_year/3","type":"function"},{"doc":"Returns the number weeks in a given year.","ref":"Cldr.Calendar.NRF.html#weeks_in_year/1","title":"Cldr.Calendar.NRF.weeks_in_year/1","type":"function"},{"doc":"Returns a Date.Range.t representing a given year.","ref":"Cldr.Calendar.NRF.html#year/1","title":"Cldr.Calendar.NRF.year/1","type":"function"},{"doc":"Calculates the year and era from the given year . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.NRF.html#year_of_era/1","title":"Cldr.Calendar.NRF.year_of_era/1","type":"function"},{"doc":"Calculates the year and era from the given year , month and day . The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;.","ref":"Cldr.Calendar.NRF.html#year_of_era/3","title":"Cldr.Calendar.NRF.year_of_era/3","type":"function"},{"doc":"","ref":"Cldr.Calendar.NRF.html#t:day/0","title":"Cldr.Calendar.NRF.day/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.NRF.html#t:month/0","title":"Cldr.Calendar.NRF.month/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.NRF.html#t:week/0","title":"Cldr.Calendar.NRF.week/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.NRF.html#t:year/0","title":"Cldr.Calendar.NRF.year/0","type":"type"},{"doc":"","ref":"Cldr.Calendar.Preference.html","title":"Cldr.Calendar.Preference","type":"module"},{"doc":"See Cldr.Calendar.Preference.calendar_from_locale/1 .","ref":"Cldr.Calendar.Preference.html#calendar_for_locale/1","title":"Cldr.Calendar.Preference.calendar_for_locale/1","type":"function"},{"doc":"See Cldr.Calendar.Preference.calendar_from_territory/1 .","ref":"Cldr.Calendar.Preference.html#calendar_for_territory/1","title":"Cldr.Calendar.Preference.calendar_for_territory/1","type":"function"},{"doc":"Return the calendar module for a locale. Arguments :locale is any locale or locale name validated by Cldr.validate_locale/2 . The default is Cldr.get_locale() which returns the locale set for the current process Returns {:ok, calendar_module} or {:error, {exception, reason}} Examples iex&gt; Cldr.Calendar.Preference . calendar_from_locale &quot;en-GB&quot; { :ok , Cldr.Calendar.GB } iex&gt; Cldr.Calendar.Preference . calendar_from_locale &quot;en-GB-u-ca-gregory&quot; { :ok , Cldr.Calendar.GB } iex&gt; Cldr.Calendar.Preference . calendar_from_locale &quot;en&quot; { :ok , Cldr.Calendar.US } iex&gt; Cldr.Calendar.Preference . calendar_from_locale &quot;fa-IR&quot; { :ok , Cldr.Calendar.Persian } iex&gt; Cldr.Calendar.Preference . calendar_from_locale &quot;fa-IR-u-ca-gregory&quot; { :ok , Cldr.Calendar.IR }","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/1","title":"Cldr.Calendar.Preference.calendar_from_locale/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/2","title":"Cldr.Calendar.Preference.calendar_from_locale/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_name/1","title":"Cldr.Calendar.Preference.calendar_from_name/1","type":"function"},{"doc":"Returns the calendar module preferred for a territory. Arguments territory is any valid ISO3166-2 code as an String.t or upcased atom() Returns {:ok, calendar_module} or {:error, {exception, reason}} Examples iex&gt; Cldr.Calendar.Preference . calendar_from_territory :US { :ok , Cldr.Calendar.US } iex&gt; Cldr.Calendar.Preference . calendar_from_territory :YY { :error , { Cldr.UnknownTerritoryError , &quot;The territory :YY is unknown&quot; } } Notes The overwhelming majority of territories have :gregorian as their first preferred calendar and therefore Cldr.Calendar.Gregorian will be returned for most territories. Returning any other calendar module would require: That another calendar is preferred over :gregorian for a territory That a calendar module is available to support that calendar. As an example, Iran (territory :IR ) prefers the :persian calendar. If the optional library ex_cldr_calendars_persian is installed, the calendar module Cldr.Calendar.Persian will be returned. If it is not installed, Cldr.Calendar.Gregorian will be returned as :gregorian is the second preference for :IR .","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1","title":"Cldr.Calendar.Preference.calendar_from_territory/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/2","title":"Cldr.Calendar.Preference.calendar_from_territory/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.Preference.html#calendar_module/1","title":"Cldr.Calendar.Preference.calendar_module/1","type":"function"},{"doc":"","ref":"Cldr.Calendar.Preference.html#calendar_modules/0","title":"Cldr.Calendar.Preference.calendar_modules/0","type":"function"},{"doc":"Implements the ~d sigils to produce dates, datetimes and naive datetimes.","ref":"Cldr.Calendar.Sigils.html","title":"Cldr.Calendar.Sigils","type":"module"},{"doc":"","ref":"Cldr.Calendar.Sigils.html#do_sigil_d/2","title":"Cldr.Calendar.Sigils.do_sigil_d/2","type":"function"},{"doc":"Implements a ~d sigil for expressing dates. Dates can be expressed in the following formats: ~d[yyyy-mm-dd] which produces a date in the Cldr.Calendar.Gregorian calendar ~d[yyyy-Wmm-dd] which produces a date in the Cldr.Calendar.IsoWeek calendar ~d[yyyy-mm-dd calendar] which produces a date in the given month-based calendar ~d[yyyy-Wmm-dd calendar] which produces a date in the given week-based calendar ~d[yyyy-mm-dd C.E Julian] which produces a date in the Cldr.Calendar.Julian calendar ~d[yyyy-mm-dd B.C.E Julian] which produces a date in the Cldr.Calendar.Julian calendar Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; ~d[2019-01-01 Gregorian] ~d[2019-01-01 Gregorian] iex&gt; ~d[2019-W01-01] ~d[2019-W01-1 ISOWeek]","ref":"Cldr.Calendar.Sigils.html#sigil_d/2","title":"Cldr.Calendar.Sigils.sigil_d/2","type":"macro"},{"doc":"Exception raised when a two datestimes are not in the same timezone","ref":"Cldr.Cldr.IncompatibleTimeZone.html","title":"Cldr.Cldr.IncompatibleTimeZone","type":"exception"},{"doc":"Exception raised when an attempt is made to use a two incompatible calendars.","ref":"Cldr.IncompatibleCalendarError.html","title":"Cldr.IncompatibleCalendarError","type":"exception"},{"doc":"Exception raised when a module is not a calendar.","ref":"Cldr.InvalidCalendarModule.html","title":"Cldr.InvalidCalendarModule","type":"exception"},{"doc":"Exception raised when two dates or times are not ordered from earlier to later","ref":"Cldr.InvalidDateOrder.html","title":"Cldr.InvalidDateOrder","type":"exception"},{"doc":"My wife's jealousy is getting ridiculous. The other day she looked at my calendar and wanted to know who May was. -- Rodney Dangerfield Introduction Calendars are curious things. For centuries people from all cultures have sought to impose human order on the astronomical movements of the earth and moon. Today, despite much of the world converging on the Proleptic Gregorian calendar, there remain many derivative and alternative ways for humans to organize the passage of time. Cldr Calendars builds on Elixir's standard Calendar module to provide additional calendars and calendar functionality intended to be of practical use. In particular Cdlr Calendars : Provides support for configurable month-based and week-based calendars that are in common use as Fiscal Year calendars for countries and organizations around the world. See Cldr.Calendar.new/3 Supports localisation of common calendar terms such as day of the week and month of the year using the CLDR data that is available for over 500 locales. See Cldr.Calendar.localize/3 Supports locale-specific knowledge of what is a weekend or a workday. See Cldr.Calendar.weekend/1 , Cldr.Calendar.weekend?/2 , Cldr.Calendar.weekdays/1 and Cldr.Calendar.weekday?/2 . Provides convenient Date.Range calculators for years, quarters, months and weeks for calendars and provides the means to move to the next and previous period in a calendar where a period may be a year, quarter, month, week or day. Supports adding or substracting periods to dates and date ranges. See Cldr.Calendar.plus/3 and Cldr.Calendar.minus/3 Includes pre-defined calendars for Gregorian (compatible with the builtin Calendar module), ISOWeek and National Retail Federation (NRF) calendars Includes returning a calendar configured to reflect the first_day_of_week and min_days_in_first_week for a given territory lor locale. See Cldr.Calendar.calendar_for_locale/2 . Includes functions to find the first, last, nearest and nth days of the week from a date. For example, find the 2nd Tuesday in November . See the documentation for Cldr.Calendar for the main public API.","ref":"readme.html","title":"Cldr Calendars","type":"extras"},{"doc":"Add ex_cldr_calendars to your deps in mix.exs . def deps do [ { :ex_cldr_calendars , &quot;~&gt; 1.17&quot; } ... ] end","ref":"readme.html#cldr-calendars-installation","title":"Cldr Calendars - Cldr Calendars Installation","type":"extras"},{"doc":"Let's say you work for Cisco Systems . Your learn that the financial year ends on the last Saturday of July. To make things easy you'd like to compare the results of this financial year to last finanical year. And you'd like to know how many days are left this quarter in order to achieve your sales targets. Here's how we do that: Define a calendar that represents Cisco's financial year Each calendar is defined as a module that implements both the Calendar and Cldr.Calendar behaviours. The details of how that is achieved isn't important at this stage. Its easy to define your own calendar module through some configuration parameters. Here's how we do that for Cisco: defmodule Cldr.Calendar.CSCO do use Cldr.Calendar.Base.Week , first_or_last : :last , day_of_year_ : 6 , month_of_year_ : 7 end This configuration says that the calendar is defined as first_or_last: :last which means we are defining a calendar in terms of when it ends (you can of course also define a calendar in terms of when it starts by setting this to :first ). The :day_of_year day is Saturday, which is in Calendar speak, the sixth day of the week. Days of the week are numbered from 1 for Monday to 7 to Sunday. The :month_of_year is July. Months are numbered from January being 1 to December being 12 . There we have it, a calendar that is based upon the definition of &quot;ends on the last Saturday of July&quot;. Dates in Cisco's calendar You might be wondering, how to we represent dates in a customised calendar like this? Thanks to the flexibility of Elixir's standard Calendar module, we can leverage existing functions to build a date. Lets build a date which is the first day of Cisco's financial year for 2019. { :ok , date } = Date . new ( 2019 , 1 , 1 , Cldr.Calendar.CSCO ) { :ok , ~d[2019-W01-1 CSCO] } That was easy. All dates are specified in the context of the specific calendar . We don't need to know what the equivalent Gregorian calendar date is. But we can find out if we want to: iex&gt; Date . convert date , Calendar.ISO { :ok , ~D[2018-07-29] } Which you will see is July 29th, 2018 - a Sunday. Since we specified that the :last day of the year is a Saturday this makes sense. You will also note that this is a date in 2018 as it should be. The year ends in July so it must start around 12 months earlier - in July of 2018. This would also mean that the last day of Fiscal Year 2018 must be July 28th, 2018. Lets check: iex&gt; Cldr.Calendar . last_gregorian_day_of_year ( 2018 , Cldr.Calendar.CSCO ) ~d[2018-07-28 Gregorian] Which you will see is the last Saturday in July for 2018. Years, quarters, months, weeks and days A common activity with calendars is selecting data in certain date ranges or iterating over those same ranges. Cldr Calendars makes that easy. Want to know what is the first quarter of Cisco's financial year in 2019? iex&gt; range = Cldr.Calendar.Interval . quarter 2019 , 1 , Cldr.Calendar.CSCO # DateRange &lt; ~d[2019-W01-1 CSCO] , ~d[2019-W13-7 CSCO] &gt; A Date.Range.t is returned which can be enumerated with any of Elixir's Enum or Stream functions. The same applies for year , month , week and day . Let's list all of the days Cisco's first quarter: iex&gt; Enum . map range , &amp; Cldr.Calendar . date_to_string / 1 [ &quot;2019-W01-1&quot; , &quot;2019-W01-2&quot; , &quot;2019-W01-3&quot; , &quot;2019-W01-4&quot; , &quot;2019-W01-5&quot; , &quot;2019-W01-6&quot; , &quot;2019-W01-7&quot; , &quot;2019-W02-1&quot; , &quot;2019-W02-2&quot; , &quot;2019-W02-3&quot; , &quot;2019-W02-4&quot; , &quot;2019-W02-5&quot; , &quot;2019-W02-6&quot; , &quot;2019-W02-7&quot; , &quot;2019-W03-1&quot; , &quot;2019-W03-2&quot; , &quot;2019-W03-3&quot; , &quot;2019-W03-4&quot; , &quot;2019-W03-5&quot; , &quot;2019-W03-6&quot; , &quot;2019-W03-7&quot; , &quot;2019-W04-1&quot; , &quot;2019-W04-2&quot; , &quot;2019-W04-3&quot; , &quot;2019-W04-4&quot; , &quot;2019-W04-5&quot; , &quot;2019-W04-6&quot; , &quot;2019-W04-7&quot; , &quot;2019-W05-1&quot; , &quot;2019-W05-2&quot; , &quot;2019-W05-3&quot; , &quot;2019-W05-4&quot; , &quot;2019-W05-5&quot; , &quot;2019-W05-6&quot; , &quot;2019-W05-7&quot; , &quot;2019-W06-1&quot; , &quot;2019-W06-2&quot; , &quot;2019-W06-3&quot; , &quot;2019-W06-4&quot; , &quot;2019-W06-5&quot; , &quot;2019-W06-6&quot; , &quot;2019-W06-7&quot; , &quot;2019-W07-1&quot; , &quot;2019-W07-2&quot; , &quot;2019-W07-3&quot; , &quot;2019-W07-4&quot; , &quot;2019-W07-5&quot; , &quot;2019-W07-6&quot; , &quot;2019-W07-7&quot; , &quot;2019-W08-1&quot; , ... ] But wait a minute, these don't look like familiar dates! Shouldn't they be formatted as &quot;yyy-mm-dd&quot;? The answer in this case is &quot;no&quot;. If you look carefully at where we asked for the date range for Cisco's first quarter of 2019 you will see %Date{calendar: Cldr.Calendar.CSCO, day: 7, month: 13, year: 2019} as the last date in the range. There is, of course, no such month as 13 in the Gregorian calendar. What's going on?","ref":"readme.html#getting-started","title":"Cldr Calendars - Getting Started","type":"extras"},{"doc":"Cisco's calendar is an example of a &quot;week-based&quot; calendar. Such week-based calendars are examples of fiscal year calendars . In Cldr Calendar , any calendar that is defined in terms of &quot;[first | last] [day of_week] of [month_of_year ]&quot; is a week-based calendar. These calendars have a year of 52 weeks duration except in &quot;leap years&quot; that have 53 weeks. The most well-known week-based calendar may be the ISO Week Calendar . How would we define that calendar in Cldr Calendars ? Easy! defmodule Cldr.Calendar.ISOWeek do use Cldr.Calendar.Base.Week , day : 1 , min_days_in_first_week : 4 end This says that the calendar starts on the first Monday in January. How do we know that? It's because :month_of_year defaults to 1 (January) and :first_or_last defaults to :first . Lets see what the first day of 2019 is in the ISOWeek calendar. iex&gt; date = Cldr.Calendar . first_day_of_year ( 2019 , Cldr.Calendar.ISOWeek ) ~d[2019-W01-1 ISOWeek] As expected, the date is expressed in terms of the calendar Cldr.Calendar.ISOWeek . What's the equivalent Gregorian day? iex&gt; Date . convert ( date , Calendar.ISO ) { :ok , ~D[2018-12-31] } That's interesting. The first day of the 2019 year in the ISO Week calendar is actually December 31st, 2018. Why is that? Week-based calendars can start or end on a given day of the week in a given month. But there is a third option: the given day of the week nearest to the start or end of the given month. This is indicated by the configuration parameter :min_days_in_first_week . For the ISO Week calendar we have min_days_in_first_week: 4 . That means that at least 4 days of the first or last week have to be in the specified :month_of_year and then we select the nearest day of the week. Hence it is possible and even common for the gregorian start of the year for a week-based calendar to be up to 6 days before or after the Gregorian start of the year. Whats the last week of 2019 in the ISO Week calendar? iex&gt; date = Cldr.Calendar.Interval . week ( 2019 , 52 , Cldr.Calendar.ISOWeek ) # DateRange &lt; ~d[2019-W52-1 ISOWeek] , ~d[2019-W52-7 ISOWeek] &gt; You'll see that for week-based calendars the date is actually stored as year, week, day where the :month field of the Date.t is actually the week in the year and :day is the day in the week.","ref":"readme.html#week-based-calendars","title":"Cldr Calendars - Week-based calendars","type":"extras"},{"doc":"The Gregorian calendar is the canonical example of a month-based calendar. It starts on January 1st and ends on December 31st each year. But not all calendars start in January and end in December. The United States fiscal year starts on October 1st and ends on September 30th The United Kingdom fiscal year starts on April 1st and ends on March 31st The Australian fiscal year starts on July 1st and ends on June 30th Cldr Calendars allows month-based calendars to be defined based upon the first or last gregorian month of the year for that calendar. Of course sometimes we also want to refer to weeks within a year although this is less common than refering to days within months. Nevertheless, a month-based calendar can also take advantage of :first_day and :min_days to determine how to calculate weeks for month-based calendars too. Here's how we define each of the three example calendars above: defmodule Cldr.Calendar.US do use Cldr.Calendar.Base.Month , month_of_year : 10 , # The year starts in October min_days_in_first_week : 4 , # The first week of the year is that with at least 4 days of October in it day_of_week : 7 # When referring to weeks, Sunday is the first day end defmodule Cldr.Calendar.UK do use Cldr.Calendar.Base.Month , month_of_year : 4 # The fiscal year starts in April end defmodule Cldr.Calendar.AU do use Cldr.Calendar.Base.Month , month_of_year : 7 , # The fiscal year starts in July year : :ending # A year refers to the ending Gregorian year. # In this example, the Australian fiscal # year 2017 is the year that starts in July # 2016 and ends in June 2017 end","ref":"readme.html#month-based-calendars","title":"Cldr Calendars - Month-based calendars","type":"extras"},{"doc":"When we talk about the Gregorian calendar we refer to the 12 months from January to December. However when we consider the various fiscal calendars, the Gregorian starting date and the Gregorian ending date will often be in different years. In these cases, when we say &quot;the 2019 US Fiscal Year&quot; what does that mean? The US fiscal year starts in October. Now we need to know whether refering to the &quot;the 2019 US Fiscal Year&quot; means the year that ends in September 2019 or the year that starts in October 2019. Some further examples are: The UK Fiscal Year starts in April. By convention, the Fiscal Year is the year that starts with April. The US Fiscal Year starts in October. By convention , the Fiscal Year is the year that has the ending October in it. The Australian Fiscal Year starts in July. By convention, the Fiscal Year is the year that ends in July. The National Retail Federation has a calendar that starts on the Saturday nearest the end of January. By convention, the Fiscal Year is the year of the starting Saturday. To cater for these varying definitions of what a Fiscal Year means, a configuration option :year can be set to :majority (which is the default), :beginning and :ending . :majority means that the Fiscal Year is the year that has the most Gregorian months in it. This is the default. :beginning means that the Fiscal Year is the year in which the first Gregorian month is found. :ending means that the Fiscal Year is the year in which the last Gregorian month is found. First lets consider the default :majority strategy. This strategy says that the Fiscal Year is that year in which the majority of Gregorian months are found. 2018 2019 2020 J F M A M J J A S O N D | J F M A M J J A S O N D | J F M A M J J A S O N D | . . . . . . . . . . . . | . . . . . . . . . . . . | . . . . . . . . . . . . | Majority Starts Jan &lt;- -- -- -- -- -- -- -- -- -- -- &gt; Starts Mar &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Starts Jun &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Starts Jul &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Starts Oct &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Ends Dec &lt;- -- -- -- -- -- -- -- -- -- -- &gt; Ends Feb &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Ends May &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Ends Jun &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; Ends Aug &lt;- -- -- -- -- -- -- -- -- -- -- -- &gt; From the diagram above we can define the following rules: For :starts calendars, we can say that the starting gregorian year is is the same as the fiscal year if the starting month is January through June inclusive. If the starting month is July through to December then the starting Gregorian year is the year prior to the fiscal year . Similarly, the ending Gregorian year is the next year for calendars that start in February through June and it's the fiscal year for calendars that start in July through December. Years that start in January end in January of the same year. For &quot;:ends&quot; calendars the rules are the opposite.","ref":"readme.html#beginning-and-ending-gregorian-years","title":"Cldr Calendars - Beginning and ending gregorian years","type":"extras"},{"doc":"Since calendars defined in Cldr.Calendar are intended to be compatible and converible to other Calendars supporting Elixir's Calendar behaviour, the configuration of calendars needs to be encapsulated. The simplest way to is to define a module that use s either Cldr.Calendar.Base.Week or Cldr.Calendar.Base.Month . This is how we have been defining calendar modules in the examples so far. A calendar module can also be created at run time. It is semantically identical to defining a static module but the module is built at run time rather than compile time. New calendars are created with the function Cldr.Calendar.new/3 . For example: iex&gt; Cldr.Calendar . new :my_new_calendar , :week , first_or_last : :first , day_of_week : 1 , min_days_in_first_week : 7 { :ok , :my_new_calendar } Calendar functions are now available on the module :my_new_calendar . iex&gt; :my_new_calendar . __config__ / 0 date_from_iso_days / 1 date_to_iso_days / 3 date_to_string / 3 datetime_to_string / 11 day_of_era / 3 day_of_week / 3 day_of_year / 3 ... CAUTION Since the runtime creation of new calendars creates a new module and therefore a new atom, this function has the potential to surface an attack vector that could exhaust the atom table and crash the BEAM. It is strongly recommended calendars be defined statically where possible. Never trust unfiltered user input to create a calendar. Fiscal Calendars for Territories Cldr Calendars can create a fiscal year calendar for many territories (countries) based upon data from the CIA world fact book . To create a fiscal year calendar for a territory use the Cldr.Calendar.FiscalYear.calendar_for/1 function. iex&gt; Cldr.Calendar.FiscalYear . calendar_for ( &quot;IS&quot; ) { :ok , Cldr.Calendar.FiscalYear.IS } iex&gt; Cldr.Calendar.FiscalYear . calendar_for ( &quot;ZZ&quot; ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; ZZ \\&quot; is unknown&quot; } } iex&gt; Cldr.Calendar.FiscalYear . calendar_for ( :AF ) { :error , { Cldr.UnknownCalendarError , &quot;Fiscal calendar is unknown for :AF&quot; } }","ref":"readme.html#calendar-creation","title":"Cldr Calendars - Calendar Creation","type":"extras"},{"doc":"Cldr Calendars provides a convenince sigil for the creation of dates in calendars. Note that it is necessary to import the Cldr.Calendar.Sigils module before using the ~d sigil. iex&gt; import Cldr.Calendar.Sigils # Create a date in the default Cldr.Calendar.Gregorian iex&gt; ~d[2019-01-01] ~d[2019-01-01 Gregorian] # Inbuilt calendars can be referred to by their shortened form iex&gt; ~d[2019-01-01 NRF] ~d[2019-W01-1 NRF] # Create a calendar and define a date in it iex&gt; Cldr.Calendar . new FiscalAU , :month , month_of_year : 7 { :ok , FiscalAU } iex&gt; ~d[2019-01-01 FiscalAU] ~d[2019-01-01 FiscalAU]","ref":"readme.html#sigil-d","title":"Cldr Calendars - Sigil ~d","type":"extras"},{"doc":"Cldr Calendars is able to localize parts of a date include the era , quarter , month and day_of_week . The CLDR provides the underlying data. The function Cldr.Calendar.localize/3 provides the required functionality. Some examples are: iex&gt; Cldr.Calendar . localize ~D[2019-01-01] , :era &quot;AD&quot; iex&gt; Cldr.Calendar . localize ~D[2019-01-01] , :day_of_week &quot;Tue&quot; iex&gt; Cldr.Calendar . localize ~D[0001-01-01] , :day_of_week &quot;Mon&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :era &quot;AD&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :quarter &quot;Q2&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :month &quot;Jun&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week &quot;Sat&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , format : :wide &quot;Saturday&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , format : :narrow &quot;S&quot; iex&gt; Cldr.Calendar . localize ~D[2019-06-01] , :day_of_week , locale : &quot;ar&quot; &quot;السبت&quot;","ref":"readme.html#date-localization","title":"Cldr Calendars - Date localization","type":"extras"},{"doc":"Intervals representing parts of a calendar can be created and compared. Since intervals are represented as a Date.Range they can also be enumerated with the Map and Stream functions. Intervals can be created for a year, quarter, month, week and day. For example: iex&gt; Cldr.Calendar.Interval . year ( 2019 ) # DateRange &lt; ~d[2019-01-01 Gregorian] , ~d[2019-12-31 Gregorian] &gt; iex&gt; Cldr.Calendar.Interval . month ( 2019 , 3 ) # DateRange &lt; ~d[2019-03-01 Gregorian] , ~d[2019-03-31 Gregorian] &gt; iex&gt; Cldr.Calendar.Interval . month ( 2019 , 3 , Cldr.Calendar.NRF ) # DateRange &lt; ~d[2019-W10-1 NRF] , ~d[2019-W13-7 NRF] &gt; iex&gt; Cldr.Calendar.Interval . week ( 2019 , 5 , Cldr.Calendar.NRF ) # DateRange &lt; ~d[2019-W05-1 NRF] , ~d[2019-W05-7 NRF] &gt; iex&gt; Cldr.Calendar.Interval . quarter ( 2019 , 3 ) # DateRange &lt; ~d[2019-07-01 Gregorian] , ~d[2019-09-30 Gregorian] &gt; Comparing Calendar Intervals Intervals can also be compared to each other and using the taxonomy of Allen's Interval Algebra a comparison will return one of 13 different relationship types between two calendar intervals: Relation Converse :precedes :preceded_by :meets :met_by :overlaps :overlapped_by :finished_by :finishes :contains :during :starts :started_by :equals :equals Some examples: iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) :meets iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-03] ) :precedes iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-03] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) :preceded_by iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-01] ) :met_by iex&gt; Cldr.Calendar.Interval . compare Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) , ...&gt; Cldr.Calendar.Interval . day ( ~D[2019-01-02] ) :equals Durations A duration is calculated as the difference in time in calendar units: years, months, days, hours, minutes, seconds and microseconds. This is useful to support formatting a string for users in easy-to-understand terms. For example 11 months, 3 days and 4 minutes is a lot easier to understand than 28771440 seconds. The package ex_cldr_units can be optionally configured to provide localized formatting of durations. If configured, the following providers must be configured in the appropriate CLDR backend module. For example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;ja&quot; ] , providers : [ Cldr.Calendar , Cldr.Number , Cldr.Unit , Cldr.List ] end To create a duration, use Cldr.Calendar.Duration.new/2 providing two dates, times or datetimes. The first date must occur before the second date. Datetimes must be in the same time zone. To format a duration into a string use Cldr.Calendar.Duration.to_string/2 . An example is: iex&gt; { :ok , duration } = Cldr.Calendar.Duration . new ( ~D[2019-01-01] , ~D[2019-12-31] ) iex&gt; Cldr.Calendar.Duration . to_string ( duration ) &quot;11 months and 30 days&quot; A duration can also be created from a Date.Range.t and CalendarInterval.t . CalendarInterval.t is defined by the wonderful calendar_interval library. iex&gt; Cldr.Calendar.Duration . new Date . range ( ~D[2020-01-01] , ~D[2020-12-31] ) { :ok , % Cldr.Calendar.Duration { day : 30 , hour : 0 , microsecond : 0 , minute : 0 , month : 11 , second : 0 , year : 0 } } iex&gt; use CalendarInterval CalendarInterval iex&gt; Cldr.Calendar.Duration . new ~I&quot;2020-01/12&quot; { :ok , % Cldr.Calendar.Duration { day : 30 , hour : 0 , microsecond : 0 , minute : 0 , month : 11 , second : 0 , year : 0 } } A duration can be added to a date. Adding to times and datetimes is not currenlty supported. An example is: iex&gt; { :ok , duration } = Cldr.Calendar.Duration . new ( ~D[2019-01-01] , ~D[2019-12-31] ) iex&gt; Cldr.Calendar . plus ~D[2019-01-01] , duration ~D[2019-12-31] Configuring a Cldr backend for localization In order to localize date parts a backend module must be defined. This is a module which hosts the CLDR data for a set of locales. The detailed information for configuring a backend is documented here . For a simple configuration the following steps may be used: Create a backend module. defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;jp&quot; , &quot;ar&quot; ] , providers : [ Cldr.Calendar , Cldr.Number ] end Optionally configure this backend as the system default in your config.exs . config :ex_cldr , default_backend : MyApp.Cldr When creating a calendar a default backend may also be defined for this calendar. defmodule MyCalendar do use Cldr.Calendar.Base.Month , month_of_year : 4 , cldr_backend : MyApp.Cldr end It is also possible to pass the name of a backend module to the Cldr.Calendar.localize/3 function by specifying the :backend option with a backend module name.","ref":"readme.html#calendar-intervals-date-ranges","title":"Cldr Calendars - Calendar Intervals (date ranges)","type":"extras"},{"doc":"The examples in this readme reflect inspecting dates as they are in Elixir 1.10. For earlier releases of Elixir add this code to your project: if Version . compare ( System . version ( ) , &quot;1.10.0-dev&quot; ) == :lt do defimpl Inspect , for : Date do def inspect ( date , opts ) do Cldr.Calendar . inspect ( date , opts ) end end end You will get a warning indicating that the existing implementation is being overwritten. This is expected.","ref":"readme.html#inspecting-calendar-dates","title":"Cldr Calendars - Inspecting calendar dates","type":"extras"},{"doc":"Copyright 2018-2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.3 released on January 31st, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Kday.nth_kday/3 for when the kday is the same as the day of the week of the date.","ref":"changelog.html#cldr-calendars-v1-17-3","title":"Changelog - Cldr Calendars v1.17.3","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.2 released on December 26th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes Cldr.Calendar.FiscalYear.calendar_for/2 . Thanks for @DaTrader for the report. Closes #10. Use Cldr.Calendar.date_to_iso_days/1 in preference to Date.to_gregorian_days/1 since the latter is only available in Elixir 1.11 and later. Thanks to @DaTrader for the report. Closes #11.","ref":"changelog.html#cldr-calendars-v1-17-2","title":"Changelog - Cldr Calendars v1.17.2","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.1 released on November 1st, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Ensure compatibility with Elixir 1.13 by marking the implementations of Calendar.year_of_era/1 as @impl true only on releases earlier than Elixir 1.13. In Elixir 1.13 the callback is Calendar.year_of_era/3 .","ref":"changelog.html#cldr-calendars-v1-17-1","title":"Changelog - Cldr Calendars v1.17.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.0 released on October 27th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updates to support CLDR release 40 via ex_cldr version 2.24 Add support for Chinese, Japanese and Korean lunisolar calendars . Adds Cldr.Calendar.year_of_era/1 that supports eras that might change at any time during a calendar year. This is primarily applicable to the Japanese calendar. Add Cldr.Calendar.Behaviour that can be use d to factor out a lot of calendar boilerplate for many (but not all) calendar types. Add year_of_era/3 as a callback in the Cldr.Calendar behaviour. This is required because at least one calendar (the Japanese) can change era on any day of the year. Bug Fixes Fix day_of_week/{3, 4} to be compatible with Elixir 1.12 and also earlier versions - and ensure dialyzer passes on consuming applications. Deprecations Don't call deprecated Cldr.Config.known_locale_names/1 , call Cldr.Locale.Loader.known_locale_names/1 instead.","ref":"changelog.html#cldr-calendars-v1-17-0","title":"Changelog - Cldr Calendars v1.17.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.0-rc.3 released on October 25th, 2021. For older changelogs please consult the release tag on GitHub Deprecations Don't call deprecated Cldr.Config.known_locale_names/1 , call Cldr.Locale.Loader.known_locale_names/1 instead.","ref":"changelog.html#cldr-calendars-v1-17-0-rc-3","title":"Changelog - Cldr Calendars v1.17.0-rc.3","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.0-rc.2 released on October 25th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix day_of_week/{3, 4} to be compatible with Elixir 1.12 and also earlier versions - and ensure dialyzer passes on consuming applications.","ref":"changelog.html#cldr-calendars-v1-17-0-rc-2","title":"Changelog - Cldr Calendars v1.17.0-rc.2","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.0-rc.1 released on October 25th, 2021. For older changelogs please consult the release tag on GitHub Deprecations Don't call deprecated Cldr.Config.get_locale/2 , use Cldr.Locale.Loader.get_config/2 instead.","ref":"changelog.html#cldr-calendars-v1-17-0-rc-1","title":"Changelog - Cldr Calendars v1.17.0-rc.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.17.0-rc.0 released on October 3rd, 2021. For older changelogs please consult the release tag on GitHub Enhancements Add support for Chinese, Japanese and Korean lunisolar calendars . Adds Cldr.Calendar.year_of_era/1 that supports eras that might change at any time during a calendar year. This is primarily applicable to the Japanese calendar. Add Cldr.Calendar.Behaviour that can be use d to factor out a lot of calendar boilerplate for many (but not all) calendar types. Add year_of_era/3 as a callback in the Cldr.Calendar behaviour. This is required because at least one calendar (the Japanese) can change era on any day of the year.","ref":"changelog.html#cldr-calendars-v1-17-0-rc-0","title":"Changelog - Cldr Calendars v1.17.0-rc.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.16.0 released on August 27th, 2021. For older changelogs please consult the release tag on GitHub This release requires a minimum of Elixir 1.10 in line with supporting the current release and the two previous releases. Therefore Elixir 1.10, 1.11 and 1.12 are supported. Bug Fixes Do not require ex_cldr_numbers as a dependency.","ref":"changelog.html#cldr-calendars-v1-16-0","title":"Changelog - Cldr Calendars v1.16.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.15.3 released on August 22nd, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes a case when Cldr.Calendar.Kday.kday_after/1 would return the same date, not the subsequent one.","ref":"changelog.html#cldr-calendars-v1-15-3","title":"Changelog - Cldr Calendars v1.15.3","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.15.2 released on August 20th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix doc errors. Thanks to @maennchen for the report. Doc errors in other ex_cldr packages are also updated.","ref":"changelog.html#cldr-calendars-v1-15-2","title":"Changelog - Cldr Calendars v1.15.2","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.15.1 released on August 8th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Add Code.ensure_loaded?(Date) when checking for whether we need to implement Date.day_of_week/3 or Date.day_of_week/4 since this changed from earlier Elixir versions.","ref":"changelog.html#cldr-calendars-v1-15-1","title":"Changelog - Cldr Calendars v1.15.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.15.0 released on July 1st, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updated to ex_cldr version 2.23.0 which has some changes to the valid territories list requiring a change in some tests. This normally wouldn't require a minor version change but doing so makes it easier to target this library as a dependency.","ref":"changelog.html#cldr-calendars-v1-15-0","title":"Changelog - Cldr Calendars v1.15.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.14.1 released on May 17th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix @impl warnings on Elixir 1.12","ref":"changelog.html#cldr-calendars-v1-14-1","title":"Changelog - Cldr Calendars v1.14.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.14.0 released on April 13th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Support creating time-base durations that are negative in direction. Date and DateTime durations must still be positive durations. For example: # Create a time-based duration that is negative in direction iex&gt; { :ok , duration } = Cldr.Calendar.Duration . new ~T[10:00:00.0] , ~T[09:00:00.0] { :ok , % Cldr.Calendar.Duration { day : 0 , hour : - 1 , microsecond : 0 , minute : 0 , month : 0 , second : 0 , year : 0 } }","ref":"changelog.html#cldr-calendars-v1-14-0","title":"Changelog - Cldr Calendars v1.14.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.13.0 released on April 8th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Fix creating durations from two Time s. Add support for CLDR 39 data release","ref":"changelog.html#cldr-calendars-v1-13-0","title":"Changelog - Cldr Calendars v1.13.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.12.1 released on April 7th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix a bug that prevented durations being created from times (as apposed to dates and datetimes)","ref":"changelog.html#cldr-calendars-v1-12-1","title":"Changelog - Cldr Calendars v1.12.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.12.0 released on November 8th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Rename Cldr.Calendar.Preference.calendar_for_locale/1 to Cldr.Calendar.Preference.calendar_from_locale/1 Rename Cldr.Calendar.Preference.calendar_for_territory/1 to Cldr.Calendar.Preference.calendar_from_territory/1 Add Cldr.Calendar.calendar_from_territory/1 Add Cldr.Calendar.calendar_from_locale/1,2","ref":"changelog.html#cldr-calendars-v1-12-0","title":"Changelog - Cldr Calendars v1.12.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.11.0 released on November 1st, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add support for CLDR 38","ref":"changelog.html#cldr-calendars-v1-11-0","title":"Changelog - Cldr Calendars v1.11.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.10.1 released on September 26th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Add a shim for default_backend/0 that delegates to Cldr.default_backend/0 or Cldr.default_backend!/0 depending on ex_cldr release. Releases from 2.18.0 use Cldr.default_backend!/0 .","ref":"changelog.html#cldr-calendars-v1-10-1","title":"Changelog - Cldr Calendars v1.10.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.10.0 released on August 29th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Supports upcoming Elixir 1.11.0. The Calendar callback for day_of_week/3 has been changed to day_of_week/4 to allow for a different start day of week. Since Cldr Calendars already supports defining calendars with different start days of the week (ie other than Monday), the impementation only supports the :default parameter. Thanks to @lostkobrakai for the report. Closes Cldr Dates Times issue #17.","ref":"changelog.html#cldr-calendars-v1-10-0","title":"Changelog - Cldr Calendars v1.10.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.9.0 released on June 7th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Calendar.plus/{3,4} that allows adding a Cldr.Calendar.Duration to a Calendar.date . Support for adding durations to datetime s is not yet available. Add support for datetimes to Cldr.Calendar.Duration.new/2 Add support for Date.Range.t and CalendarInterval.t to Cldr.Calendar.Duration.new/1 Bug Fixes More complete test coverage on durations with some additional corner case fixes","ref":"changelog.html#cldr-calendars-v1-9-0","title":"Changelog - Cldr Calendars v1.9.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.8.1 released on June 4th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fix duration calculation when the year and month are the same and the day of the last date is greater than the day of the first date","ref":"changelog.html#cldr-calendars-v1-8-1","title":"Changelog - Cldr Calendars v1.8.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.8.0 released on May 4th, 2020. For older changelogs please consult the release tag on GitHub Breaking Change (that you might notice but probably won't) The min_days_in_first_week for the calendar Cldr.Calendar.Gregorian is changed to be 1 rather than the previous value of 4 . This only affects week-related processing for the calendar. The reason for the change is that the majority of territories have a preference for 1 for min_days_in_first_week so Cldr.Calendar.Gregorian more closely aligns to majority expectations. Breaking changes (that you shouldn't notice) The return result from Cldr.Calendar.new/3 may return {:module_already_exists, module} . It previously returned {:already_exists, module} Bug Fixes Use backend.get_locale/0 instead of Cldr.get_locale/0 for all options Ensure that the default values for a locale's min_days and first_day_of_week are correctly applied in Cldr.Calendar.new/3 . Any values passed as options take precedence over those defined for a locale. Enhancements Add Cldr.Calendar.calendar_for_locale/2 which will create (or return) a gregorian-based calendar configured for the supplied locale. This typically means applying the correct values for min_days and first_day_of_week . For now all calendars created in this way are Gregorian monthly calendars. Add Cldr.Calendar.Preference.calendar_for_locale/1 which returns the appropriate calendar for a locale based upon locale preferences and configured calendars. Unlike Cldr.Calendar.calendar_for_locale/2 , this function may return non-Gregorian calendars. For example, for the locale fa-IR it will return Cldr.Calendar.Persian (if ex_cldr_calendars_persian is configured) because that is the locale preference. Add Cldr.Calendar.Preference.calendar_for_territory/1 provides the same result as Cldr.Calendar.Preference.calendar_for_locale/2 except that argument is a territory code. Add Cldr.Calendar.Preference.preferences_for_territory/1 Add Cldr.Calendar.validate_calendar/1 which returns {:ok, calendar} if the argument is a Cldr.Calendar calendar module or {:error, {exception, reason}} if not.","ref":"changelog.html#cldr-calendars-v1-8-0","title":"Changelog - Cldr Calendars v1.8.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.7.1 released on January 26th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fix doc link in MyApp.Cldr.Calendar.strftime_options!/2","ref":"changelog.html#cldr-calendars-v1-7-1","title":"Changelog - Cldr Calendars v1.7.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.7.0 released on January 2nd, 2020. For older changelogs please consult the release tag on GitHub Enhancements Remove call to deprecated Code.ensure_compiled?/1 in Elixir 1.10","ref":"changelog.html#cldr-calendars-v1-7-0","title":"Changelog - Cldr Calendars v1.7.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.6.0 released on December 9th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds support for localizing Persian, Coptic and Ethiopic calendar localization. These calendars are published separately but they rely upon localization support from this package.","ref":"changelog.html#cldr-calendars-v1-6-0","title":"Changelog - Cldr Calendars v1.6.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.5.1 released on November 10th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Calendar.next/3 and Cldr.Calendar.previous/3 for months with week-based calendars. Thanks to @bglusman for the report. Closes #3. Note that the use of the :coerce option is recommended in most cases.","ref":"changelog.html#cldr-calendars-v1-5-1","title":"Changelog - Cldr Calendars v1.5.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.5.0 released on November 3rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds MyApp.Cldr.Calendar.strftime_options!/2 to return a keyword list of options that can be applied to NimbleStrftime.format/3","ref":"changelog.html#cldr-calendars-v1-5-0","title":"Changelog - Cldr Calendars v1.5.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.4.0 released on September 14th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adjusts &lt;calendar&gt;.add/3 to &lt;calendar&gt;.add/5 so that it takes individual date and time elements and not formal structs. This is consistent with other calendar behaviours.","ref":"changelog.html#cldr-calendars-v1-4-0","title":"Changelog - Cldr Calendars v1.4.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.3.0 released on September 1st, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds &lt;calendar&gt;.add/3 to add :quarter or :week to a naive datetime. This adds to the existing support for :year and :month .","ref":"changelog.html#cldr-calendars-v1-3-0","title":"Changelog - Cldr Calendars v1.3.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.2.0 released on August 31st, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Calendar.Duration to create a duration struct defining the difference between two dates, times or date_times as a calendar difference in years, months, days, hours, minutes, seconds and microseconds. See Cldr.Calendar.Duration.new/2 and Cldr.Calendar.Duration.to_string/1 . Changes sigil_d/2 from a function to a macro so that dates are created at compile time","ref":"changelog.html#cldr-calendars-v1-2-0","title":"Changelog - Cldr Calendars v1.2.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.1.0 released on August 30th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds &lt;calendar&gt;.add/3 to add :year or :month to a naive datetime. This function supports the library calendar_interval allowing intervals to be used with ex_cldr_calendars [ https://hex.pm/packages/ex_cldr_calendars]. The mid-term objective is to add add/3 to the Calendar behaviour and thereby also simplify the interface to CalendarInterval . Changes the output of to_string/1 to consistently use the full name of the calendar module, not an appreviated name.","ref":"changelog.html#cldr-calendars-v1-1-0","title":"Changelog - Cldr Calendars v1.1.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v1.0.0 released on June 16th, 2019. For older changelogs please consult the release tag on GitHub Breaking changes The format produced by inspecting a Date (or DateTime or NaiveDateTime) has changed. The parsing of dates in sigil_d (the ~d sigil) has also changed in order to facilitate roundtrip conversions. Previously a date would inspect as (using the NRF calendar) ~d[2019-W01-1]NRF . It now inspects as ~d[2019-W01-1 NRF] . The same approach is used for all calendars. See the examples in Cldr.Calendar.Sigils . This change is applicable to Elixir 1.10 and later. The calendar configuration option :min_days has been renamed :min_days_in_first_week . The configuration option :day has been renamed to :day_of_week and the option :month has been renamed to :month_of_year . An exception will be raised if existing calendars are not updated. An exception will be raised if a calendar is configured with an unknown option. Enhancements Implements inspect_date/4 , inspect_datetime/11 , inspect_naive_datetime/8 and inspect_time/5 for all Cldr.Calendar calendars. This implementation supports the revised Inspect protocol implementation for Date , Time , DateTime and NaiveDateTime structs. The purpose of that change is to allow customer calendars to be inspected. This change is applicable to Elixir 1.10 and later. Adds Cldr.Calendar.week_of_month/1 and Cldr.Calendar callback week_of_month/4 to return the week of a month. The weeks are calculated on the basis of the calendar configuration. As a result, the week of the month, like the week of the year, may be in a different Gregorian year and month compared to the specified date. Adds Cldr.Calendar.weeks_in_year/1 to return the number of weeks in a year. Adds a calendar configuration where weeks start on the first day of the year. This configuration is valid only for :month based calendars. The configuration option day: :first triggers this behaviour. This configuration can result in the last week of the year being less than 7 days. Adds Cldr.Calendar.inspect/2 that can be used as an :inspect_fun option in Inspect.Opts for Elixir version 1.9. It will not be required for Elixir 1.10 and later since this commit introduces inspect_* callbacks for Date , Time , DateTime and NaiveDateTime . An :inspect_fun can be configured in IEx by: iex&gt; IEx . configure ( inspect : [ inspect_fun : &amp; Cldr.Calendar . inspect / 2 ] ) :ok Bug Fixes Ensure that Cldr.Calendar callbacks return a Calendar.ISO calendar if called with one (either as part of a date or as a separate argument). Ensure the return calendar types of a an Interval are Calendar.ISO is the date provided is Calendar.ISO Fix Cldr.Calendar.plus/4 for :months when the month wraps into the previous year(s) Fix sigil_d to correctly parse ISO Week dates that have only a single digit day","ref":"changelog.html#cldr-calendars-v1-0-0","title":"Changelog - Cldr Calendars v1.0.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.9.0 released on June 9th, 2019. For older changelogs please consult the release tag on GitHub Breaking changes Depends on Elixir 1.8 and above since it requires recent Calendar functionality.","ref":"changelog.html#cldr-calendars-v0-9-0","title":"Changelog - Cldr Calendars v0.9.0","type":"extras"},{"doc":"This is the changelog for Cldr v0.8.0 released on June 8th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds option :type to Cldr.Calendar.localize/3 . This determines the format type to be localized. The valid types are :format (the default) or :stand_alone . Add Cldr.Calendar.day_periods/2 to support localization of the day periods of a time Add Cldr.Calendar.default_calendar/0 . Returns Cldr.Calendar.Gregorian Add Cldr.Calendar.default_cldr_calendar/0 . Returns :gregorian","ref":"changelog.html#cldr-calendars-v0-8-0","title":"Changelog - Cldr Calendars v0.8.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.7.0 released on June 1st, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes Moved year/1 , quarter/1 , month/1 , week/1 and day/1 to a new module Cldr.Calendar.Interval Enhancements Adds Cldr.Calendar.Interval.compare/2 to compare two intervals (date ranges) using Allen's Interval Algebra taxonomy. Defaults the calendar to Cldr.Calendar.Gregorian for Cldr.Calendar.Interval.year/2 , Cldr.Calendar.Interval.quarter/3 , Cldr.Calendar.Interval.month/3 , Cldr.Calendar.Interval.week/3 and Cldr.Calendar.Interval.day/3","ref":"changelog.html#cldr-calendars-v0-7-0","title":"Changelog - Cldr Calendars v0.7.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.6.0 released on April 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Remove the need for nimble_csv as a dependency","ref":"changelog.html#cldr-calendars-v0-6-0","title":"Changelog - Cldr Calendars v0.6.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.5.0 released on April 21th, 2019. For older changelogs please consult the release tag on GitHub Breaking changes Cldr.Calendar.localize/3 for :days_of_week now returns a list of 2-tuples that are of the format {day_of_week, day_name} . Enhancements Add Cldr.Calendar.localize/6 which localises numbers as part of a date without parameter checking. This is considered a private implementation for now.","ref":"changelog.html#cldr-calendars-v0-5-0","title":"Changelog - Cldr Calendars v0.5.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.4.1 released on April 19th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix calculation of days_in_month for the last month in long year of a week-based calendar","ref":"changelog.html#cldr-calendars-v0-4-1","title":"Changelog - Cldr Calendars v0.4.1","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.4.0 released on April 19th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Calendar.interval_stream/3 which returns a stream function that when enumerated generates a list of dates with a specified precision of either :years , :quarters , :months , :weeks or :days . This function has the same arguments and generates the same results as Cldr.Calendar.interval/3 except it generates the results lazily. Adds :days_of_week option to Cldr.Calendar.localize/3 which returns a list of the localized names of the days of the week in calendar order. Adds calendar_base/0 to identify whether the calendar is week or month based. Bug Fixes Fix Cldr.Calendar.day_of_week/1 for week-based calendars","ref":"changelog.html#cldr-calendars-v0-4-0","title":"Changelog - Cldr Calendars v0.4.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.3.0 released on April 16th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Calendar.interval/3 which generates an enumerable list of dates with a specified precision of either :years , :quarters , :months , :weeks or :days . Examples: iex&gt; import Cldr.Calendar.Sigils Cldr.Calendar.Sigils iex&gt; d = ~d[2019-01-31] % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 1 , year : 2019 } iex&gt; d2 = ~d[2019-05-31] % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 5 , year : 2019 } iex&gt; Cldr.Calendar . interval d , 3 , :months [ % Date { calendar : Cldr.Calendar.Gregorian , day : 28 , month : 2 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 3 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 30 , month : 4 , year : 2019 } ] iex&gt; Cldr.Calendar . interval d , d2 , :months [ % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 1 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 28 , month : 2 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 3 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 30 , month : 4 , year : 2019 } , % Date { calendar : Cldr.Calendar.Gregorian , day : 31 , month : 5 , year : 2019 } ]","ref":"changelog.html#cldr-calendars-v0-3-0","title":"Changelog - Cldr Calendars v0.3.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.2.0 released on April 14th, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes All calendars now return {year, month, day} tuples from date_from_iso_days/1 . Previously in some cases they returned a Date.t first_day_of_year/1 and last_day_of_year/1 , first_gregorian_day_of_year/1 and last_gregorian_day_of_year/1 now all return a Date.t or an error tuple. Previously the returned result types were inconsistent. Remove first_gregorian_day_of_year/1 and last_gregorian_day_of_year/1 from Cldr.Calendar callbacks. Enhancements Adds Cldr.Calendar.Julian implementing the Julian calendar. This calendar does not implement week/2 , week_of_year/3 or iso_week_of_year/3 . Bug Fixes Fixes calculating negative offsets for months in a week-based calendar. Thanks to @bglusman. Closes #2.","ref":"changelog.html#cldr-calendars-v0-2-0","title":"Changelog - Cldr Calendars v0.2.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars v0.1.0 released on April 5th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial release. See the README for a description of this project.","ref":"changelog.html#cldr-calendars-v0-1-0","title":"Changelog - Cldr Calendars v0.1.0","type":"extras"}]